package com.lantone.qc.kernel.catalogue.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.label.DiagLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.regex.Matcher;
import java.util.regex.Pattern;


/**
 * @ClassName :BEH03302
 * @Description :产科检查中破膜未破与胎膜早破诊断不符
 * @Author : 尤伟豪
 * @Date: 2022-04-13 16:28
 */
/*1.查证【入院记录】>>【体格检查】>>【专科检查】或【产科检查】或【胎膜】字段内容中有任一能匹配正则【pdzz--破膜未破描述正则】，则继续。
        2.查证【入院记录】>>【初步诊断】或【补充诊断】或【修正诊断】中是否有诊断能匹配【胎膜早破-疾病列表】中任一疾病名称，
        或有任一能匹配正则【pdzz--胎膜早破正则】，则提示。*/
@Component
public class BEH03302 extends QCCatalogue {

/*    //匹配正则
    public boolean getCompile(String regex, String physical){

       Boolean i = false;
        Pattern pattern = Pattern.compile(regex);
        Matcher matcher= pattern.matcher(physical);
        if (matcher.find()){
           i = true;
        }
        return i;

    }*/
/*    //匹配疾病
    public boolean getContains(String diagtext){
   boolean i = false;
   if(diagtext.contains("胎膜早破") || diagtext.contains("足月胎膜早破") || diagtext.contains("早产胎膜早破")
           || diagtext.contains("胎膜早破")){
           i = true;
         }
     return i;
    }*/
    public  void start(InputInfo inputInfo, OutputInfo outputInfo) {


        status.set("0");
        //判断入院记录是否为空
        if (inputInfo.getBeHospitalizedDoc() == null) {
            return;
        }
        String physical = inputInfo.getBeHospitalizedDoc().getStructureMap().get("体格检查");
        //判断如果体格检查为空则去查找专科检查字段，没有则继续
        if(physical == null){
             physical = inputInfo.getBeHospitalizedDoc().getStructureMap().get("专科检查");
        }
        //判断入院记录中的体格检查中的相字段是否匹配正则
        if (StringUtil.isNotBlank(physical)) {
            boolean flag = false;
            String regex = "(?<!([未否无没不非]|排除)[^。，；｡,;]{0,20})[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:(?:胎膜)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:未破|未见破|没有破|没破)|(?:没破膜|未破膜))(?!([^。，；｡,;]{0,3}([:：\\t](否|无|从不|从未|未发现|未见|未诉|没有)|(否|无|从不|从未|未发现|未见|未诉|没有)(\\\\b|[。，；｡,;\\f\\n\\r\\t]))))";
            Pattern pattern = Pattern.compile(regex);
            Matcher matcher = pattern.matcher(physical);
            if (matcher.find()) {
                flag = true;
            }
            if (flag) {
                String diagregex ="(?<!([未否无没不非]|排除)[^。，；｡,;]{0,20})[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:(?:胎膜)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:早破|早期破裂))(?!([^。，；｡,;]{0,3}([:：\\t](否|无|从不|从未|未发现|未见|未诉|没有)|(否|无|从不|从未|未发现|未见|未诉|没有)(\\\\b|[。，；｡,;\\f\\n\\r\\t]))))";
                DiagLabel initdiagLabel = inputInfo.getBeHospitalizedDoc().getInitialDiagLabel();
                //对入院记录中的初步症断进行判断是否否有诊断能匹配【胎膜早破-疾病列表】中任一疾病或是否有诊断能匹配【胎膜早破-疾病列表】中任一疾病
                if(initdiagLabel != null) {
                    String initDiagLabelText = initdiagLabel.getText();
                    if (StringUtil.isNotBlank(initDiagLabelText)) {
                        if (initDiagLabelText.contains("胎膜早破") || initDiagLabelText.contains("足月胎膜早破") || initDiagLabelText.contains("早产胎膜早破")
                                || initDiagLabelText.contains("胎膜早破")) {
                            status.set("1");
                            return;
                        }
                        Pattern patterninit = Pattern.compile(diagregex);
                        Matcher matcherinit = patterninit.matcher(initDiagLabelText);
                        if (matcherinit.find()) {
                            status.set("1");
                            return;
                        }
                    }
                }
                DiagLabel revisediagLabel = inputInfo.getBeHospitalizedDoc().getRevisedDiagLabel();
                //对入院记录中的补充症断进行判断是否否有诊断能匹配【胎膜早破-疾病列表】中任一疾病或是否有诊断能匹配【胎膜早破-疾病列表】中任一疾病
                if(revisediagLabel != null) {
                    String revisedDiagLabelText = revisediagLabel.getText();
                    if (StringUtil.isNotBlank(revisedDiagLabelText)) {
                        if (revisedDiagLabelText.contains("胎膜早破") || revisedDiagLabelText.contains("足月胎膜早破") || revisedDiagLabelText.contains("早产胎膜早破")
                                || revisedDiagLabelText.contains("胎膜早破")) {
                            status.set("1");
                            return;
                        }
                        Pattern patternrevised = Pattern.compile(diagregex);
                        Matcher matcherrevised = patternrevised.matcher(revisedDiagLabelText);
                        if (matcherrevised.find()) {
                            status.set("1");
                            return;
                        }
                    }
                }
              /*  String suppleDiagLabelText = inputInfo.getBeHospitalizedDoc().getSuppleDiagLabel().getText();*/
                DiagLabel supplediagLabel = inputInfo.getBeHospitalizedDoc().getSuppleDiagLabel();
                //对入院记录中的修正症断进行判断是否否有诊断能匹配【胎膜早破-疾病列表】中任一疾病或是否有诊断能匹配【胎膜早破-疾病列表】中任一疾病
                if(supplediagLabel != null) {
                    String suppleDiagLabelText = supplediagLabel.getText();
                    if (StringUtil.isNotBlank(suppleDiagLabelText)) {
                        if (suppleDiagLabelText.contains("胎膜早破") || suppleDiagLabelText.contains("足月胎膜早破") || suppleDiagLabelText.contains("早产胎膜早破")) {
                            status.set("1");
                            return;
                        }
                        Pattern patternsupple = Pattern.compile(diagregex);
                        Matcher matchersupple = patternsupple.matcher(suppleDiagLabelText);
                        if (matchersupple.find()) {
                            status.set("1");
                            return;
                        }
                    }
                }
            }
        }

    }

/*    public static void main(String[] args) {
        String diagregex ="(?<!([未否无没不非]|排除)[^。，；｡,;]{0,20})[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:(?:胎膜)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:早破|早期破裂))(?!([^。，；｡,;]{0,3}([:：\\t](否|无|从不|从未|未发现|未见|未诉|没有)|(否|无|从不|从未|未发现|未见|未诉|没有)(\\\\b|[。，；｡,;\\f\\n\\r\\t]))))";
        Map<String,Object> map = new HashMap<>();

        String suppleDiagLabelText = "胎膜早破";
              *//*  if(StringUtil.isNotBlank(suppleDiagLabelText)) {
                    if (suppleDiagLabelText.contains("胎膜早破") || suppleDiagLabelText.contains("足月胎膜早破") || suppleDiagLabelText.contains("早产胎膜早破")
                            || suppleDiagLabelText.contains("胎膜早破")) {
                        map.put("code", 101);
                        System.out.println(map);
                    }*//*
                    Pattern patternsupple = Pattern.compile(diagregex);
                    Matcher matchersupple = patternsupple.matcher(suppleDiagLabelText);
                    if (matchersupple.find()) {
                        map.put("code", 102);
                        System.out.println(map);
                    }


    }*/
}