package com.lantone.qc.kernel.catalogue.behospitalized;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.client.SimilarityServiceClient;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.entity.Annotation;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.model.label.DiagLabel;
import com.lantone.qc.pub.model.vo.SimilarityVo;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;


/**
 * @ClassName : BEH03327
 * @Description : 入院记录有补充诊断【外（会）阴裂伤】，首页无【外（会）阴裂伤诊断】
 * @Author : wsy
 * @Date: 2022-04-14 17:28
 */
@Component
public class BEH03327 extends QCCatalogue {
    @Autowired
    SimilarityServiceClient similarityServiceClient;

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * （入院记录和病案首页）任一不存在则通过
         * 1.查证【入院记录】>>【补充诊断】中是否有诊断能匹配【阴道或外阴（会阴）裂伤-疾病列表】中的疾病名称，或诊断能匹配正则【pdzz--阴道或外（会）阴裂伤】（参见正则列表），有则继续，且把能匹配的诊断（疾病）记存为：【list_A】(可能为1个或多个疾病)
         * 2.查证【病案首页】>>【出院诊断】中，是否有任一个疾病和【list_A】中的疾病相同或相似（算法模型计算两个疾病的相似度，大于某个相似阈值即可），否则提示。
         *
         * */
        status.set("0");
        List<String> diagListWords = Content.JBLB_HYLS;
        //获取入院记录
        BeHospitalizedDoc beHospitalizedDoc = inputInfo.getBeHospitalizedDoc();
        //获取病案首页
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        if (beHospitalizedDoc == null || firstPageRecordDoc == null) {
            return;
        }
        //匹配疾病正则
        String rex = Content.PDZZ_HYLS;
        //创建存储能匹配疾病的集合
        List<String> diagList = new ArrayList<>();
        //补充诊断
        DiagLabel suppleDiagLabel = beHospitalizedDoc.getSuppleDiagLabel();
        if (suppleDiagLabel != null) {
            List<Diag> diagLists = suppleDiagLabel.getDiags();
            if (ListUtil.isNotEmpty(diagLists)) {
                diagLists.stream().filter(diag -> StringUtil.isNotEmpty(diag.getHospitalDiagName()) && (diagListWords.contains(diag.getHospitalDiagName()) || diag.getHospitalDiagName().matches(rex))).forEach(diag ->
                        diagList.add(diag.getHospitalDiagName()));
            }
        }
        //如果疾病集合为空则直接返回
        if (ListUtil.isEmpty(diagList)) {
            return;
        }
        List<String> diagCollectList = diagList.stream().distinct().collect(Collectors.toList());

        //获取病案首页疾病并判断
        List<String> diags = new ArrayList<>();

        //获取出院诊断
        String leaveDiagStr = firstPageRecordDoc.getStructureMap().get("出院诊断");
        if (StringUtil.isNotEmpty(leaveDiagStr)) {
            List<Map<String, String>> leaveDiagList = (List<Map<String, String>>) JSONArray.parse(leaveDiagStr);
            leaveDiagList.stream().filter(i -> StringUtil.isNotEmpty(i.get("诊断名称"))).forEach(i ->
                    diags.add(i.get("诊断名称")));
        }
        if (ListUtil.isEmpty(diags)) {
            return;
        }

        if (ListUtil.isNotEmpty(diagCollectList)) {
            status.set("-1");
            for (String diag : diags) {
                for (String diagCollectName : diagCollectList) {
                    if (StringUtil.isNotEmpty(diag) && StringUtil.isNotEmpty(diagCollectName)) {
                        if (getLikeRate(diag, diagCollectName)) {
                            status.set("0");
                            return;
                        }
                    }
                }
            }
            return;
        }
    }

    private boolean getLikeRate(String text_1, String text_2) {
        JSONArray similarContent = new JSONArray();
        JSONObject detailContent = new JSONObject();
        detailContent.put("text_1", text_1);
        detailContent.put("text_2", text_2);
        similarContent.add(detailContent);
        //存储CRF完整所需结构数据
        SimilarityVo similarityVo = new SimilarityVo();
        similarityVo.setData(similarContent);
        //获取CRF模型返回数据
        JSONArray data = getAnnotation(similarityServiceClient, similarityVo).getData();
        double likeRate = 0d;
        if (data.size() > 0) {
            JSONObject dataContent = data.getJSONObject(0);
            likeRate = dataContent.getDoubleValue("like_rate");
        }
        if (likeRate > 0.9) {
            return true;
        }
        return false;
    }

    private Annotation getAnnotation(SimilarityServiceClient similarityServiceClient, SimilarityVo similarityVo) {
        Annotation annotation = new Annotation();
        try {
            String annotation_str = similarityServiceClient.getAnnotation(similarityVo);
            annotation = JSON.parseObject(annotation_str, Annotation.class);
        } catch (Exception ex) {
            ex.printStackTrace();
        } finally {
            return annotation;
        }
    }
}