package com.lantone.qc.kernel.catalogue.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;


/**
 * @ClassName : BEH03330
 * @Description : 入院记录预产期应为末次月经月份加9或减3，日子加8
 * @Author : wsy
 * @Date: 2022-04-14 17:28
 */
@Component
public class BEH03331 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 1.查证【入院记录】，是否有“预产期”和“末次月经”两个字段，任一不存在则直接返回。
         * 2.查证【入院记录】>>【末次月经月份】字段内容，字段内容：月+9（月+9大于12则月-3）记为：A【末次月经日】字段内容：日+7（日+7大于30则返回月份，月改记为:A+1,日：日+7-30）记为:B
         * 3.查证【入院记录】>>【预产期】中的内容与A（月）B（日）对比，内容一致则通过，否则提示
         * */
        status.set("0");
        //获取入院记录
        BeHospitalizedDoc beHospitalizedDoc = inputInfo.getBeHospitalizedDoc();
        if (beHospitalizedDoc == null) {
            return;
        }
        //预产期
        String eDOC = beHospitalizedDoc.getStructureMap().get("预产期");
        //末次月经
        String lastMP = beHospitalizedDoc.getStructureMap().get("末次月经");
        //末次月经月份
        String lastMPMonth = beHospitalizedDoc.getStructureMap().get("末次月经月份");
        //末次月经日
        String lastMPDay = beHospitalizedDoc.getStructureMap().get("末次月经日");
        if (StringUtil.isBlank(eDOC) || StringUtil.isBlank(lastMP) || StringUtil.isBlank(lastMPMonth) || StringUtil.isBlank(lastMPDay)) {
            return;
        }

        try {
            int lastMPMonthNum = strConvertInt(lastMPMonth) + 9 > 12 ? strConvertInt(lastMPMonth) - 3 : strConvertInt(lastMPMonth) + 9;
            int lastMPDayNum = strConvertInt(lastMPDay) + 7;
            if (lastMPDayNum > 30) {
                lastMPMonthNum = lastMPMonthNum + 1;
                lastMPDayNum = lastMPDayNum - 30;
            }
            if (lastMPMonthNum != lastMPDayNum) {
                status.set("-1");
                return;
            }
        } catch (Exception e) {

        }

    }

    //String转int
    private int strConvertInt(String str) {
        return Integer.parseInt(str);
    }

}