package com.lantone.qc.kernel.catalogue.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.client.SimilarityServiceClient;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.model.label.DiagLabel;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.model.label.VitalLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;


/**
 * @ClassName : BEH03335
 * @Description : 入院记录诊断为【妊娠合并子宫瘢痕】，体检内无切口愈合情况
 * @Author : wsy
 * @Date: 2022-04-14 17:28
 */
@Component
public class BEH03335 extends QCCatalogue {
    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 1.查证【入院记录】>>【初步诊断】或【补充诊断】或【修正诊断】中是否有诊断能匹配【妊娠合并子宫瘢痕/妊娠合并子宫疤痕/剖宫产瘢痕妊娠/子宫瘢痕处妊娠/剖宫产史的妊娠/妊娠合并宫颈瘢痕】中任一疾病名称，或能匹配正则【pdzz--是否妊娠合并子宫瘢痕的正则】，有则继续。
         *
         * 2.查证【入院记录】>>【体格检查/体查/专科检查/体检/腹部检查】中，是否有切口愈合情况描述，通过能否匹配正则【pdzz--是否有切口愈合情况描述的正则】判定（病历举例：“腹部切口愈合良好”“切口*愈合”“腹*刀口*愈合”“腹*见*手术切口”“腹*见*术*疤痕”“腹*术*瘢痕”），否则提示。
         *
         * */
        status.set("0");
        List<String> diagListWords = Content.JBLB_RZZGBH;
        //获取入院记录
        BeHospitalizedDoc beHospitalizedDoc = inputInfo.getBeHospitalizedDoc();
        if (beHospitalizedDoc == null) {
            return;
        }
        //匹配[pdzz--是否妊娠合并子宫瘢痕的正则]
        String rex = Content.PDZZ_RZZGBH;
        //匹配[pdzz--是否有切口愈合情况描述的正则]
        String QKRex = Content.PDZZ_QKYHQKMS;
        //创建存储能匹配疾病的集合
        List<String> diagList = new ArrayList<>();
        //入院记录不为空，获取其诊断信息
        //初步诊断
        DiagLabel initialDiagLabel = beHospitalizedDoc.getInitialDiagLabel();
        //修正诊断
        DiagLabel revisedDiagLabel = beHospitalizedDoc.getRevisedDiagLabel();
        //补充诊断
        DiagLabel suppleDiagLabel = beHospitalizedDoc.getSuppleDiagLabel();
        if (initialDiagLabel != null) {
            List<Diag> diagLists = initialDiagLabel.getDiags();
            if (ListUtil.isNotEmpty(diagLists)) {
                diagLists.stream().filter(diag -> StringUtil.isNotEmpty(diag.getHospitalDiagName()) && (diagListWords.contains(diag.getHospitalDiagName()) || diag.getHospitalDiagName().matches(rex))).forEach(diag ->
                        diagList.add(diag.getHospitalDiagName()));
            }

        }
        if (revisedDiagLabel != null) {
            List<Diag> diagLists = revisedDiagLabel.getDiags();
            if (ListUtil.isNotEmpty(diagLists)) {
                diagLists.stream().filter(diag -> StringUtil.isNotEmpty(diag.getHospitalDiagName()) && (diagListWords.contains(diag.getHospitalDiagName()) || diag.getHospitalDiagName().matches(rex))).forEach(diag ->
                        diagList.add(diag.getHospitalDiagName()));
            }
        }
        if (suppleDiagLabel != null) {
            List<Diag> diagLists = suppleDiagLabel.getDiags();
            if (ListUtil.isNotEmpty(diagLists)) {
                diagLists.stream().filter(diag -> StringUtil.isNotEmpty(diag.getHospitalDiagName()) && (diagListWords.contains(diag.getHospitalDiagName()) || diag.getHospitalDiagName().matches(rex))).forEach(diag ->
                        diagList.add(diag.getHospitalDiagName()));
            }
        }

        //如果疾病集合为空则直接返回
        if (ListUtil.isEmpty(diagList)) {
            return;
        }

        boolean flag = true;
        //获取体格检查
        VitalLabel vitalLabel = beHospitalizedDoc.getVitalLabel();
        if (vitalLabel != null) {
            if (vitalLabel.getText().matches(QKRex)) {
                flag = false;
            }
        }
        if (flag) {
            status.set("-1");
            return;
        }
    }

}