package com.lantone.qc.kernel.catalogue.behospitalized;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.client.SimilarityServiceClient;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.model.label.DiagLabel;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;


/**
 * @ClassName : BEH03336
 * @Description : 入院记录诊断为【妊娠合并子宫瘢痕】，既往史无相关病史描述
 * @Author : wsy
 * @Date: 2022-04-14 17:28
 */
@Component
public class BEH03336 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 1.查证【入院记录】>>【初步诊断】或【补充诊断】或【修正诊断】中是否有【妊娠合并子宫瘢痕/妊娠合并子宫疤痕/剖宫产瘢痕妊娠/子宫瘢痕处妊娠/剖宫产史的妊娠/妊娠合并宫颈瘢痕】中任一疾病名称，或能匹配正则【pdzz--是否妊娠合并子宫瘢痕的正则】，有则继续。
         *
         * 2.查证【入院记录】>>【既往史】中，是否有【子宫瘢痕相关病史描述】，通过能否匹配正则【pdzz--既往史是否有子宫瘢痕相关手术史正则】判定（病历举例：“曾行剖宫产”“剖宫产”“剖腹产”“子宫*术”“子宫*切”“子宫*摘除”“子宫*疤痕”“子宫*瘢痕”），否则提示。
         *
         * */
        status.set("0");
        List<String> diagListWords = Content.JBLB_RZZGBH;
        //获取入院记录
        BeHospitalizedDoc beHospitalizedDoc = inputInfo.getBeHospitalizedDoc();
        if (beHospitalizedDoc == null) {
            return;
        }
        //匹配[pdzz--是否妊娠合并子宫瘢痕的正则]
        String rex = Content.PDZZ_RZZGBH;
        //匹配[pdzz--既往史是否有子宫瘢痕相关手术史正则]
        String QKRex = Content.PDZZ_ZGBHOP;
        //创建存储能匹配疾病的集合
        List<String> diagList = new ArrayList<>();
        //入院记录不为空，获取其诊断信息
        //初步诊断
        DiagLabel initialDiagLabel = beHospitalizedDoc.getInitialDiagLabel();
        //修正诊断
        DiagLabel revisedDiagLabel = beHospitalizedDoc.getRevisedDiagLabel();
        //补充诊断
        DiagLabel suppleDiagLabel = beHospitalizedDoc.getSuppleDiagLabel();
        if (initialDiagLabel != null) {
            List<Diag> diagLists = initialDiagLabel.getDiags();
            if (ListUtil.isNotEmpty(diagLists)) {
                diagLists.stream().filter(diag -> StringUtil.isNotEmpty(diag.getHospitalDiagName()) && (diagListWords.contains(diag.getHospitalDiagName()) || diag.getHospitalDiagName().matches(rex))).forEach(diag ->
                        diagList.add(diag.getHospitalDiagName()));
            }

        }
        if (revisedDiagLabel != null) {
            List<Diag> diagLists = revisedDiagLabel.getDiags();
            if (ListUtil.isNotEmpty(diagLists)) {
                diagLists.stream().filter(diag -> StringUtil.isNotEmpty(diag.getHospitalDiagName()) && (diagListWords.contains(diag.getHospitalDiagName()) || diag.getHospitalDiagName().matches(rex))).forEach(diag ->
                        diagList.add(diag.getHospitalDiagName()));
            }
        }
        if (suppleDiagLabel != null) {
            List<Diag> diagLists = suppleDiagLabel.getDiags();
            if (ListUtil.isNotEmpty(diagLists)) {
                diagLists.stream().filter(diag -> StringUtil.isNotEmpty(diag.getHospitalDiagName()) && (diagListWords.contains(diag.getHospitalDiagName()) || diag.getHospitalDiagName().matches(rex))).forEach(diag ->
                        diagList.add(diag.getHospitalDiagName()));
            }
        }

        //如果疾病集合为空则直接返回
        if (ListUtil.isEmpty(diagList)) {
            return;
        }

        //获取入院记录既往史中疾病信息
        List<String> diags = new ArrayList<>();
        //获取既往史
        PastLabel pastLabel = beHospitalizedDoc.getPastLabel();
        if (pastLabel != null) {
            List<Diag> diagLists = pastLabel.getDiags();
            if (ListUtil.isNotEmpty(diagLists)) {
                diagLists.stream().filter(diag -> StringUtil.isNotEmpty(diag.getHospitalDiagName()) && (diagListWords.contains(diag.getHospitalDiagName()) || diag.getHospitalDiagName().matches(QKRex))).forEach(diag ->
                        diags.add(diag.getHospitalDiagName()));
            }
        }
        if (ListUtil.isEmpty(diags)) {
            status.set("-1");
            return;
        }
    }

}