package com.lantone.qc.kernel.catalogue.firstcourserecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstCourseRecordDoc;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.doc.MedicalRecordInfoDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

/**
 * @ClassName : FIRC03295
 * @Description : 产科首次病程录年龄不应小于14岁或大于54岁
 * @Author : 沈乾
 * @Date: 2022-04-13 17:35
 */
@Component
/*
        1.查证【首次病程录】，有则继续。
        2.查证【住院信息表】或【病案首页的（出院科室/出院科别）】是否为包含（产科）字段，不包含妇产科，有则继续。
        3.查证【首次病程录】>>【年龄】字段内容，并判断字段内容的数字是否小于14或大于54，是则提示"
*/

public class FIRC03295 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        FirstCourseRecordDoc firstCourseRecordDoc = inputInfo.getFirstCourseRecordDoc();
        MedicalRecordInfoDoc medicalRecordInfoDoc = inputInfo.getMedicalRecordInfoDoc();
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        if (firstCourseRecordDoc == null) {
            return;
        }
        if (medicalRecordInfoDoc == null) {
            return;
        }
        //定义变量，并将住院信息表中的出院科室信息赋值给变量
        String behDeptName = medicalRecordInfoDoc.getStructureMap().get("beh_dept_name");
        //定义变量，并将病案首页中的出院科室信息赋值给变量
        String aa = firstPageRecordDoc.getStructureMap().get("出院科别");
        //条件判断
        if (StringUtil.isNotBlank(behDeptName) && !behDeptName.contains("产科") && behDeptName.contains("妇产科")
                && StringUtil.isNotBlank(aa) && !aa.contains("产科") && aa.contains("妇产科")) {
            return;
        }
        //定义变量储存从首次病程录中获取的年龄字段信息
        String age = firstCourseRecordDoc.getStructureMap().get("年龄");
        //判断年龄字段是否为空，且将年龄字段中可能出现的岁和年进行替换
        if (StringUtil.isNotBlank(age)) {
            age = age.replace("年", "").replace("岁", "");
            //定义变量储存强制转化类型后的age
            int ageNum = Integer.parseInt(age);
            if (ageNum < 14 || ageNum > 54) {
                status.set("-1");
                return;
            }
        }
    }
}
