package com.lantone.qc.kernel.catalogue.firstcourserecord;

import com.google.common.collect.Lists;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstCourseRecordDoc;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.doc.MedicalRecordInfoDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.List;

/**
 * @ClassName : FIRC03299
 * @Description : 首次病程录性别和科室不符，性别不应为男性
 * @Author : 沈乾
 * @Date: 2022-04-14 15:25
 */
@Component
public class FIRC03299 extends QCCatalogue {

    private List<String> genderList = Lists.newArrayList("男", "男性", "1", "1男", "1男性", "1.男");

    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         1.查证【首次病程录】，有则继续
         2.查证【住院信息表】是否包含（产科/妇科/妇产科）任一字段，有则继续。
         3.查证【首次病程录】>>【性别】字段内容, 字段内容为【男#男性#1#1男#1男性#1.男】任一，则提示。

         */
        status.set("0");
        //1.查证首次病程录，有则继续;再查证住院信息表
        FirstCourseRecordDoc firstCourseRecordDoc = inputInfo.getFirstCourseRecordDoc();
        MedicalRecordInfoDoc medicalRecordInfoDoc = inputInfo.getMedicalRecordInfoDoc();
        if (firstCourseRecordDoc == null) {
            return;
        }
        if (medicalRecordInfoDoc == null) {
            return;
        }
        //定义变量，并将住院信息表中的出院科室信息赋值给变量
        String behDeptName = medicalRecordInfoDoc.getStructureMap().get("beh_dept_name");
        //定义变量，并将病案首页中的出院科室信息赋值给变量
        String aa = firstCourseRecordDoc.getStructureMap().get("出院科别");
        //定义列表储存字段
        List<String> disease_name = Arrays.asList("产科", "妇科", "妇产科");
        //定义一个布尔类型，用于最后的判断
        boolean l = false;
        //遍历列表内容，
        for (int i = 0; i < disease_name.size(); i++) {
            String name = disease_name.get(i);//定义一个变量储存每一次遍历时获取的列表值
            if ((StringUtil.isNotBlank(aa) && aa.contains(name)) || (StringUtil.isNotBlank(behDeptName) && behDeptName.contains(name))) {//用contains判断变量abc中是否包含列表中的任一项
                l = true;
                break;
            }
        }
        if (l) {
            //定义变量储存从病案首页中获取的性别字段信息
            String gender = firstCourseRecordDoc.getStructureMap().get("性别");
            if (StringUtil.isNotBlank(gender) && genderList.contains(gender)) {
                status.set("-1");
                return;
            }
        }
    }
}

