package com.lantone.qc.kernel.catalogue.firstcourserecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;


/**
 * @ClassName :FIRC03303
 * @Description :产科检查中破膜未破与胎膜早破诊断不符
 * @Author : 尤伟豪
 * @Date: 2022-04-15 14:28
 */
/*1.查证【首次病程录】>>【专科检查】或【产科检查】或【查体】字段内容中有任一能匹配正则【pdzz--破膜未破描述正则】，有则继续。
        2.查证【首次病程录】>>【初步诊断】或【补充诊断】或【修正诊断】中是否有诊断能匹配【胎膜早破-疾病列表】中任一疾病名称
        或有任一能匹配正则【pdzz--胎膜早破正则】，则提示。*/
@Component
public class FIRC03303 extends QCCatalogue {
    //判断是否匹配正则
    //physical为需要匹配的字段
    //破膜未破正则匹配
    public static boolean getCompile(String physical){

        String regex = "(?<!([未否无没不非]|排除)[^。，；｡,;]{0,20})[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:(?:胎膜)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:未破|未见破|没有破|没破)|(?:没破膜|未破膜))(?!([^。，；｡,;]{0,3}([:：\t](否|无|从不|从未|未发现|未见|未诉|没有)|(否|无|从不|从未|未发现|未见|未诉|没有)(\\b|[。，；｡,;\f\n\r\t]))))";
        Pattern pattern = Pattern.compile(regex);
        Matcher matcher= pattern.matcher(physical);
        if (matcher.find()){
            return true;
        }
            return false;


    }
    //破膜破了正则匹配
    public static boolean getIsCompile(String physical){

        String regex = "(?<!([未否无没不非]|排除)[^。，；｡,;]{0,20})[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:(?:胎膜)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:早破|早期破裂))(?!([^。，；｡,;]{0,3}([:：\\t](否|无|从不|从未|未发现|未见|未诉|没有)|(否|无|从不|从未|未发现|未见|未诉|没有)(\\\\b|[。，；｡,;\\f\\n\\r\\t]))))";
        Boolean i = false;
        Pattern pattern = Pattern.compile(regex);
        Matcher matcher= pattern.matcher(physical);
        if (matcher.find()){
            i = true;
        }
        return i;

    }
    public  void start(InputInfo inputInfo, OutputInfo outputInfo) {

        status.set("0");
        //判断首次病程录是否为空
        if (inputInfo.getFirstCourseRecordDoc() == null) {
            return;
        }
        //定义变量
        String a = inputInfo.getFirstCourseRecordDoc().getStructureMap().get("专科检查");
        String b = inputInfo.getFirstCourseRecordDoc().getStructureMap().get("产科检查");
        String c = inputInfo.getFirstCourseRecordDoc().getStructureMap().get("查体");
        String d = inputInfo.getFirstCourseRecordDoc().getStructureMap().get("初步诊断");
        String e = inputInfo.getFirstCourseRecordDoc().getStructureMap().get("补充诊断");
        String f = inputInfo.getFirstCourseRecordDoc().getStructureMap().get("修正诊断");
        //判断三个字段是否匹配未破膜正则
        if(StringUtil.isNotBlank(a)&&getCompile(a) || StringUtil.isNotBlank(b)&&getCompile(b) || StringUtil.isNotBlank(c)&&getCompile(c)){
           //建立一个list集合来存储相关疾病
            List<String> disease_name = Arrays.asList("胎膜早破","足月胎膜早破","早产胎膜早破");
            //for循环来遍历每一个病例与相关字段匹配
            for(int i =0;i < disease_name.size();i++) {
                String name = disease_name.get(i);
                //如果匹配到相关列表则提示，程序终止。
                if (StringUtil.isNotBlank(d) && d.contains(name) || StringUtil.isNotBlank(e) && e.contains(name) || StringUtil.isNotBlank(f) && f.contains(name)) {
                    status.set("1");
                    return;
                }
            }
                //匹配到胎膜早破正则,输出，
                    if(StringUtil.isNotBlank(d) && getIsCompile(d) || StringUtil.isNotBlank(d) && getIsCompile(e) || StringUtil.isNotBlank(d) && getIsCompile(f)){
                        status.set("1");
                        return;
                    }

            }


        }



    }


