package com.lantone.qc.kernel.catalogue.firstcourserecord;

import com.google.common.collect.Lists;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstCourseRecordDoc;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : FIRC03311
 * @Description :  首次病程录性别和诊断不符（异位妊娠）
 * @Author : wsy
 * @Date: 2022-04-15 15:51
 */
@Component
public class FIRC03311 extends QCCatalogue {

    private List<String> genderList = Lists.newArrayList("男", "男性", "1", "1男", "1男性", "1.男");

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 1.查证【首次病程录】，有则继续
         * 2.查证【首次病程录】>>【初步诊断】或【补充诊断】或【修正诊断】，中是否有诊断能匹配【异位妊娠-疾病列表】中任一疾病名称，或能匹配正则【pdzz--是否异位妊娠的正则】，有则继续。
         * 3.查证【首次病程录】>>【性别】字段内容, 字段内容为【男#男性#1#1男#1男性#1.男#1.男性】任一，则提示。
         *
         *  */
        status.set("0");
        //异位妊娠-疾病列表
        List<String> diagListWords = Content.JBLB_YWRS;
        //获取首次病程记录
        FirstCourseRecordDoc firstCourseRecordDoc = inputInfo.getFirstCourseRecordDoc();
        if (firstCourseRecordDoc == null) {
            return;
        }
        //匹配疾病正则
        String rex = Content.PDZZ_YWRS;
        //创建存储能匹配疾病的集合
        List<String> diagList = new ArrayList<>();
        //获取首次病程记录中诊断
        //初步诊断
        String initialDiagText = firstCourseRecordDoc.getStructureMap().get("初步诊断");
        //补充诊断
        String suppleDiagText = firstCourseRecordDoc.getStructureMap().get("补充诊断");
        //修正诊断
        String revisedDiagText = firstCourseRecordDoc.getStructureMap().get("修正诊断");
        if (StringUtil.isNotBlank(initialDiagText) && diagListWords.contains(initialDiagText) && initialDiagText.matches(rex)) {
            diagList.add(initialDiagText);
        }
        if (StringUtil.isNotBlank(suppleDiagText) && diagListWords.contains(suppleDiagText) && suppleDiagText.matches(rex)) {
            diagList.add(suppleDiagText);
        }
        if (StringUtil.isNotBlank(revisedDiagText) && diagListWords.contains(revisedDiagText) && revisedDiagText.matches(rex)) {
            diagList.add(revisedDiagText);
        }
        //如果疾病集合为空则直接返回
        if (ListUtil.isEmpty(diagList)) {
            return;
        }
        //性别
        String gender = firstCourseRecordDoc.getStructureMap().get(Content.gender);

        if (genderList.contains(gender)) {
            status.set("-1");
            return;
        }

    }
}