package com.lantone.qc.kernel.catalogue.firstcourserecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstCourseRecordDoc;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.model.label.DiagLabel;
import com.lantone.qc.pub.model.label.DiagnosisLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;


/**
 * @ClassName : FIRC03326
 * @Description : 首次病程录诊断依据中孕产次应与诊断孕产次符合
 * @Author : wsy
 * @Date: 2022-04-14 17:28
 */
@Component
public class FIRC03326 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 1.查证【首次病程录】>>【初步诊断】内是否包含有【孕产次-疾病列表】中任一疾病名称，若无则通过。（怀孕次数和生产次数，真实诊断名称举例：“孕2产1孕40周LOA待产”“G2P1”，均表示目前怀孕2次，生产1次）。获取的所有诊断逐个去匹配正则【[Gg孕][^1-9]?([1-9])[^1-9]?[Pp产][^1-9]?([0-9])[^1-9]】，成功匹配后，捕获的匹配组1的数字字符记为【孕次A】，捕获的匹配组2的数字字符记为【产次B】，没有诊断能匹配则直接返回。
         * 2.查证【首次病程录】>>【诊断依据】内容去匹配正则【[Gg孕][^1-9]?([1-9])[^1-9]?[Pp产][^1-9]?([0-9])[^1-9]】，成功匹配后，捕获的匹配组1的数字字符记为【孕次A1】，捕获的匹配组2的数字字符记为【产次B1】，没有匹配则直接返回。
         * 3.判断：【孕次A】==【孕次A1】，且【产次B】==【产次B1】，则通过，否则提示
         *
         * */
        status.set("0");
        List<String> diagListWords = Content.JBLB_YCC;
        //获取首次病程
        FirstCourseRecordDoc firstCourseRecordDoc = inputInfo.getFirstCourseRecordDoc();
        if (firstCourseRecordDoc == null) {
            return;
        }
        //创建存储能匹配疾病的集合
        List<String> diagList = new ArrayList<>();
        //存放诊断依据中孕产次
        String Diagnosis = "";
        //存放孕次A
        String graNumA = "";
        //存放产次B
        String parityNumB = "";
        //存放孕次A1
        String graNumA1 = "";
        //存放产次B1
        String parityNumB1 = "";
        //首次病程录不为空，获取孕产次
        //初步诊断
        DiagLabel initialDiagLabel = firstCourseRecordDoc.getInitialDiagLabel();
        if (initialDiagLabel != null) {
            List<Diag> diagLists = initialDiagLabel.getDiags();
            if (ListUtil.isNotEmpty(diagLists)) {
                diagLists.stream().filter(diag -> StringUtil.isNotEmpty(diag.getHospitalDiagName()) && (diagListWords.contains(diag.getHospitalDiagName()))).forEach(diag -> {
                    Pattern pattern = Pattern.compile("[Gg孕][^1-9]?([1-9])[^1-9]?[Pp产][^1-9]?([0-9])[^1-9]");
                    Matcher matcher = pattern.matcher(diag.getHospitalDiagName());
                    if (matcher.find()) {
                        diagList.add(matcher.group());
                    }
                });
            }
        }

        //如果疾病集合为空则直接返回
        if (ListUtil.isEmpty(diagList)) {
            return;
        }

        //第一个诊断为准
        if (diagList.get(0).contains("孕")) {
            graNumA = diagList.get(0).substring(diagList.get(0).indexOf("孕"), Math.min(diagList.get(0).length(), diagList.get(0).indexOf("孕") + 1));
        }
        if (diagList.get(0).contains("产")) {
            parityNumB = diagList.get(0).substring(diagList.get(0).indexOf("产"), Math.min(diagList.get(0).length(), diagList.get(0).indexOf("产") + 1));
        }

        if (StringUtil.isEmpty(graNumA) || StringUtil.isEmpty(parityNumB)) {
            return;
        }

        //诊断依据
        DiagnosisLabel diagnosisLabel = firstCourseRecordDoc.getDiagnosisLabel();
        if (diagnosisLabel != null) {
            String text = diagnosisLabel.getText();
            if (StringUtil.isNotBlank(text)) {
                Pattern pattern = Pattern.compile("[Gg孕][^1-9]?([1-9])[^1-9]?[Pp产][^1-9]?([0-9])[^1-9]");
                Matcher matcher = pattern.matcher(text);
                if (matcher.find()) {
                    Diagnosis = matcher.group();
                }
            }
        }
        if (StringUtil.isEmpty(Diagnosis)) {
            return;
        }
        if (Diagnosis.contains("孕")) {
            graNumA1 = Diagnosis.substring(Diagnosis.indexOf("孕"), Math.min(Diagnosis.length(), Diagnosis.indexOf("孕") + 1));
        }
        if (Diagnosis.contains("产")) {
            parityNumB1 = Diagnosis.substring(Diagnosis.indexOf("产"), Math.min(Diagnosis.length(), Diagnosis.indexOf("产") + 1));
        }

        if (StringUtil.isEmpty(graNumA1) || StringUtil.isEmpty(parityNumB1)) {
            return;
        }

        if (strConvertInt(graNumA) != strConvertInt(graNumA1) || strConvertInt(parityNumB) != strConvertInt(parityNumB1)) {
            status.set("-1");
            return;
        }

    }

    //String转int
    private int strConvertInt(String str) {
        return Integer.parseInt(str);
    }
}