package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : FIRP03179
 * @Description :出院主要诊断疾病编码未填写
 * @Author : wsy
 * @Date: 2020-03-16 13:31
 */
@Component
public class FIRP03179 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        if (inputInfo.getFirstPageRecordDoc() != null && inputInfo.getFirstPageRecordDoc().getStructureExtMap() != null) {
            Map<String, Object> firstpageStructureMap = inputInfo.getFirstPageRecordDoc().getStructureExtMap();
            List<Map<String, String>> outpatientEmergencyDiag = (List) firstpageStructureMap.get(Content.dischargeDiag);
            if (outpatientEmergencyDiag == null || outpatientEmergencyDiag.size() == 0) {
                return;
            }

            long count = outpatientEmergencyDiag.stream().filter(diag -> {
                boolean flag = false;
                if (StringUtil.isNotBlank(diag.get("诊断类别"))
                        && diag.get("诊断类别").contains("主要诊断")
                        && StringUtil.isBlank(diag.get("诊断编码"))) {
                    flag = true;
                }
                return flag;
            }).count();

            if (count > 0) {
                status.set("-1");
            }
        }
    }
}