package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : FIRP03184
 * @Description :出院其他诊断入院病情未填写
 * @Author : wsy
 * @Date: 2021-10-12 14:01
 */
@Component
public class FIRP03184 extends QCCatalogue {

    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        if (inputInfo.getFirstPageRecordDoc() != null && inputInfo.getLeaveHospitalDoc() != null) {
            Map<String, Object> firstpageStructureMap = inputInfo.getFirstPageRecordDoc().getStructureExtMap();
            List<Map<String, String>> dischargeDiag = (List) firstpageStructureMap.get(Content.dischargeDiag);
            if (ListUtil.isEmpty(dischargeDiag)) {
                return;
            }
            for (Map<String, String> diagMap : dischargeDiag) {
                String diagSort = diagMap.get("诊断类别");
                String beHStatus = diagMap.get("入院情况");
                String diagName = diagMap.get("诊断名称");
                //若诊断类别为其他诊断，入院情况为空，提示缺陷
                if (StringUtil.isBlank(diagSort) && diagSort.contains("其他诊断") && StringUtil.isBlank(beHStatus)) {
                    status.set("-1");
                    info.set(diagName);
                    return;
                }
            }
        }
    }
}