package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.AnesthesiaRecordDoc;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.model.entity.Operation;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import com.mysql.jdbc.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : FIRP03193
 * @Description :  麻醉方式未填写
 * @Author : wsy
 * @Date: 2022-04-15 15:51
 */
@Slf4j
@Component
public class FIRP03193 extends QCCatalogue {
    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         *判断是否有麻醉（以下任一满足则证明有麻醉）
         * 1.查证首页>>麻醉费＞0，第一栏麻醉方式必填。
         * 2.查证首页>>【手术及操作名称】, 字段内容名称属性为手术或介入治疗时（参考手术或介入治疗LT002），对应的麻醉方式必填。(未实现)
         * 3.查证首页>>【手术及操作编码】, 字段内容名称属性为手术或介入治疗编码时（参考手术或介入治疗LT002），对应的麻醉方式必填。(未实现)
         * 4.查证：有(麻醉记录/手术记录/术后首次病程记录/麻醉术后访视记录）时，第一栏麻醉方式必填。
         *
         * */
        status.set("0");
        //麻醉方式
        String anesthesiaMethod = "";
        //获取病案首页
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        //获取麻醉记录
        List<AnesthesiaRecordDoc> anesthesiaRecordDocs = inputInfo.getAnesthesiaRecordDocs();
        //获取手术
        List<OperationDoc> operationDocs = inputInfo.getOperationDocs();

        if (firstPageRecordDoc == null) {
            return;
        }

        Map<String, Object> firstPageRecordDocStructureMap = firstPageRecordDoc.getStructureExtMap();
        //获取麻醉方式
        List<Map<String, String>> mapList = (List<Map<String, String>>) firstPageRecordDocStructureMap.get(Content.operative_information);
        if (ListUtil.isNotEmpty(mapList)) {
            anesthesiaMethod = mapList.get(0).get("麻醉方式");
        }

        if (StringUtil.isNotEmpty(anesthesiaMethod)) {
            return;
        }
        //获取病案首页中麻醉费
        String narcosisFee = firstPageRecordDoc.getStructureMap().get("麻醉费");
        if (StringUtil.isNotBlank(narcosisFee)) {
            try {
                int narFee = Integer.parseInt(narcosisFee);
                //麻醉费大于0且麻醉方式为空
                if (narFee > 0 && StringUtil.isEmpty(anesthesiaMethod)) {
                    status.set("-1");
                    return;
                }
            } catch (Exception e) {
                log.error("FIRP03193 int转换失败。。。。。。。。" + e.getMessage(), e);
            }
        }

        //首页麻醉方式为空，麻醉记录。手术病程不为空，提示缺陷
        if (StringUtil.isEmpty(anesthesiaMethod) && (ListUtil.isNotEmpty(operationDocs)|| ListUtil.isNotEmpty(anesthesiaRecordDocs))) {
            status.set("-1");
            return;
        }
    }
}