package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.google.common.collect.Lists;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstCourseRecordDoc;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @ClassName : FIRP03238
 * @Description :  血型填写不在值域范围内
 * @Author : wsy
 * @Date: 2022-04-15 15:51
 */
@Component
public class FIRP03238 extends QCCatalogue {

    private List<String> bloodTypeList = Lists.newArrayList("A型", "B型", "O型", "AB型", "不详", "未查", "A", "B", "O", "AB", "1", "2", "3", "4", "5", "6");

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 1.查证【病案首页】，有则继续
         * 2.查证【病案首页】>>【血型】字段内容为空则返回，内容为“-”，不为（A型/B型/O型/AB型/不详/未查/A/B/O/AB/1/2/3/4/5/6)内任一则触发规则。
         *
         *  */
        status.set("0");
        //获取病案首页
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        if (firstPageRecordDoc == null) {
            return;
        }
        //血型
        String bloodType = firstPageRecordDoc.getStructureMap().get(Content.bloodType);
        if (StringUtil.isBlank(bloodType)) {
            return;
        }

        if (bloodType.equals("-") || !bloodTypeList.contains(bloodType)) {
            status.set("-1");
            return;
        }

    }
}