package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.doc.MedicalRecordInfoDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

/**
 * @ClassName : FIRP03294
 * @Description : 产科病案首页年龄不应小于14岁或大于54岁
 * @Author : 沈乾
 * @Date: 2022-04-14 15:31
 */
@Component
/*
        1.查证【病案首页】，有则继续。
        2.查证【住院信息表】或【病案首页的（出院科室/出院科别）】是否为包含（产科）字段，不包含妇产科，有则继续。
        3.查证【病案首页】>>【年龄】字段内容，并判断字段内容的数字是否小于14或大于54，是则提示
*/

public class FIRP03294 extends QCCatalogue {

    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        MedicalRecordInfoDoc medicalRecordInfoDoc = inputInfo.getMedicalRecordInfoDoc();
        if (firstPageRecordDoc == null) {
            return;
        }
        if (medicalRecordInfoDoc == null) {
            return;
        }
        String behDeptName = medicalRecordInfoDoc.getStructureMap().get("beh_dept_name");

        String aa = firstPageRecordDoc.getStructureMap().get("出院科别");

        if (StringUtil.isNotBlank(behDeptName) && !behDeptName.contains("产科") && behDeptName.contains("妇产科")
                && StringUtil.isNotBlank(aa) && !aa.contains("产科") && aa.contains("妇产科")) {
            return;
        }
        String age = firstPageRecordDoc.getStructureMap().get("年龄");
        if (StringUtil.isNotBlank(age)) {
            age = age.replace("年", "").replace("岁", "");
            int ageNum = Integer.parseInt(age);
            if (ageNum < 14 || ageNum > 54) {
                status.set("-1");
                return;
            }
        }

    }
}
