package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.doc.MedicalRecordInfoDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.List;

/**
 * @ClassName : FIRP03298
 * @Description : 病案首页性别和科室不符，性别不应为男性
 * @Author : 沈乾
 * @Date: 2022-04-14 15:25
 */
@Component
/*
        1.查证【病案首页】，有则继续
        2.查证【住院信息表】或【病案首页的（出院科室/出院科别）】是否为包含（产科/妇科/妇产科）任一字段，有则继续。
        3.查证【病案首页】>>【性别】字段内容, 字段内容为【男#男性#1#1男#1男性#1.男#1.男性】任一，则提示。"
*/

public class FIRP03298 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        //1.查证病案首页，有则继续;再查证住院信息表
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        MedicalRecordInfoDoc medicalRecordInfoDoc = inputInfo.getMedicalRecordInfoDoc();
        if (firstPageRecordDoc == null) {
            return;
        }
        if(medicalRecordInfoDoc == null){
            return;
        }
        //定义变量，并将住院信息表中的出院科室信息赋值给变量
        String bb = medicalRecordInfoDoc.getStructureMap().get("beh_dept_name");
        //定义变量，并将病案首页中的出院科室信息赋值给变量
        String aa = firstPageRecordDoc.getStructureMap().get("出院科别");
        //定义列表储存字段
        List<String> disease_name = Arrays.asList("产科","妇科","妇产科");
        //定义一个布尔类型，用于最后的判断
        boolean l = false;
        //遍历列表内容，
        for (int i = 0; i < disease_name.size(); i++) {
            String name = disease_name.get(i);//定义一个变量储存每一次遍历时获取的列表值
            if ((StringUtil.isNotBlank(aa) && aa.contains(name)) || (StringUtil.isNotBlank(bb) && bb.contains(name))){//用contains判断变量abc中是否包含列表中的任一项
                l = true;
                break;
            }
        }
        if (l) {


            //定义变量储存从病案首页中获取的性别字段信息
            String sex = firstPageRecordDoc.getStructureMap().get("性别");
            if (StringUtil.isNotBlank(sex) && (sex.contains("男") || sex.contains("男性") || sex.contains("1")
                    || sex.contains("1男") || sex.contains("1男性") || sex.contains("1.男") || sex.contains("1.男性"))) {

                status.set("-1");
                return;

            }

        }
    }
}

