package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.doc.MedicalRecordInfoDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * @ClassName : FIRP03300
 * @Description : 产科病案首页血型不能填不详或未查
 * @Author : 沈乾
 * @Date: 2022-04-15 15:25
 */
@Component
/*
        1.查证【病案首页】，有则继续
        2.查证【住院信息表】或【病案首页的（出院科室/出院科别）】是否为包含（产科）字段，排除妇产科，有则继续。
        3.查证【入院时间】和当前时间已超24小时，是则继续。
        4.查看【病案首页】>>【血型】字段内容, 字段内容为【不详#未查#6#5#5不详#6未查#5.不详#6.未查】任一，则提示。"
*/

public class FIRP03300 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo){
        //查证【病案首页】，有则继续
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        if(firstPageRecordDoc == null){
            return;
        }
        MedicalRecordInfoDoc medicalRecordInfoDoc = inputInfo.getMedicalRecordInfoDoc();
        if(medicalRecordInfoDoc == null){
            return;
        }
        //定义变量，并将住院信息表中的出院科室信息赋值给变量
        String behDeptName = medicalRecordInfoDoc.getStructureMap().get("beh_dept_name");
        //定义变量，并将病案首页中的出院科室信息赋值给变量
        String aa = firstPageRecordDoc.getStructureMap().get("出院科别");
        //条件判断
        if (StringUtil.isNotBlank(behDeptName) && !behDeptName.contains("产科") && behDeptName.contains("妇产科")
                && StringUtil.isNotBlank(aa) && !aa.contains("产科") && behDeptName.contains("妇产科")) {
            return;
        }


        long l = Long.parseLong("1440");//定义超出的24小时也就是1440分钟为long类型
        Date now = new Date();//获取当前时间
        String beHospital_Date = medicalRecordInfoDoc.getStructureMap().get("behospital_date");//获取入院时间
        Date beginTime = StringUtil.parseDateTime(beHospital_Date);//将获得的时间转化成date类型
        if(!CatalogueUtil.compareTime(beginTime,now,l)){
            return;
        }




        String blood = firstPageRecordDoc.getStructureMap().get("血型");
        if (StringUtil.isNotBlank(blood) && (blood.contains("不详") || blood.contains("未查")
                || blood.contains("6") || blood.contains("5") || blood.contains("5不详")
                || blood.contains("6未查") || blood.contains("5.不详") || blood.contains("6.未查"))) {

            status.set("-1");
            return;

        }
    }
}
