package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.doc.MedicalRecordInfoDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : FIRP03301
 * @Description : 产科出院主要诊断编码应为“O”码
 * @Author : 沈乾
 * @Date: 2022-04-15 16:25
 */
@Component
/*
        1.查证【病案首页】，有则继续
        2.查证【病案首页】内（出院科室/出院科别）或【住院信息表科室】，为包含“产科”不为“妇产科”
        3.查看【出院主要诊断编码】字段内容,未填写则不报，填写情况下为字母“O”开头的编码，则通过，否则提示。"

*/
public class FIRP03301 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        //查证【病案首页】，有则继续
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        if (firstPageRecordDoc == null) {
            return;
        }
        String a = firstPageRecordDoc.getStructureMap().get("出院科别");


        //查证住院信息表
        MedicalRecordInfoDoc medicalRecordInfoDoc = inputInfo.getMedicalRecordInfoDoc();
        if(medicalRecordInfoDoc == null){
            return;
        }
        //定义变量，并将住院信息表中的出院科室信息赋值给变量
        String behDeptName = medicalRecordInfoDoc.getStructureMap().get("beh_dept_name");


        //条件判断
        if (StringUtil.isNotBlank(behDeptName) && !behDeptName.contains("产科") && behDeptName.contains("妇产科")
                && StringUtil.isNotBlank(a) && !a.contains("产科") && a.contains("妇产科")) {
            return;
        }

        //获取出院诊断信息
        Map<String, Object> firstpageStructureMap = inputInfo.getFirstPageRecordDoc().getStructureExtMap();
        List<Map<String, String>> dischargeDiag = (List) firstpageStructureMap.get(Content.dischargeDiag);
        if(dischargeDiag == null){
            return;
        }
        //获取诊断编码
        String s = dischargeDiag.get(0).get(Content.diagCode);
        char fir = s.charAt(0);
        if(s == null){
            return;
        } else if(fir == 0){

            status.set("-1");
            return;
        } else{
            return;
        }




    }
}
