package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.alibaba.fastjson.JSONArray;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.entity.Operation;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : FIRP03310
 * @Description :新生儿出生体重和分娩记录内不一致
 * @Author : wsy
 * @Date: 2022-04-15 15:51
 */
@Component
public class FIRP03310 extends QCCatalogue {
    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         *病案首页和分娩记录任一为空则通过
         * 1.获取病案首页结构化数据"新生儿出生体重"，若为空或“—”则返回。
         * 2.查证【分娩记录】，获取新生儿>>体重（或新生儿体重）或体重*克，取阿拉伯数字与首页【新生儿出生体重】对比，不一致则提示。
         *
         * */
        status.set("0");
        String newbornWeight = "";
        //获取病案首页
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        //获取分娩记录
        if (firstPageRecordDoc == null) {
            return;
        }
        if (inputInfo.getFirstPageRecordDoc() != null && inputInfo.getFirstPageRecordDoc().getStructureMap() != null) {
            Map<String, String> firstpageStructureMap = inputInfo.getFirstPageRecordDoc().getStructureMap();
            newbornWeight = firstpageStructureMap.get(Content.newbornWeight);
        }
        
        if (StringUtil.isBlank(newbornWeight) || newbornWeight.contains("-")) {
            return;
        }

        //2.查证【分娩记录】，获取新生儿>>体重（或新生儿体重）或体重*克，取阿拉伯数字与首页【新生儿出生体重】对比，不一致则提示。

    }
}