package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.google.common.collect.Lists;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : FIRP03312
 * @Description :  病案首页性别和诊断不符（异位妊娠）
 * @Author : wsy
 * @Date: 2022-04-15 15:51
 */
@Component
public class FIRP03312 extends QCCatalogue {

    private List<String> icdCodeList = Lists.newArrayList("男", "男性", "1", "1男", "1男性", "1.男");

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 1.查证【病案首页】，有则继续
         * 2.查证【病案首页】>>【出院诊断】或【门急诊诊断】或【门（急）诊诊断】或【门诊诊断】中是否有诊断能匹配【异位妊娠-疾病列表】中任一疾病名称，或能匹配正则【pdzz--是否异位妊娠的正则】，有则继续。
         * 3.查证【病案首页】>>【性别】字段内容, 字段内容为【男#男性#1#1男#1男性#1.男】任一，则提示。
         *
         *  */
        status.set("0");
        //异位妊娠-疾病列表
        List<String> diagListWords = Content.JBLB_YWRS;
        //获取病案首页
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        if (firstPageRecordDoc == null) {
            return;
        }
        //匹配疾病正则
        String rex = Content.PDZZ_YWRS;
        //创建存储能匹配疾病的集合
        List<String> diagList = new ArrayList<>();
        //获取病案首页疾病并判断
        //获取出院诊断
        List<Map<String, String>> leaveDiagList = (List) firstPageRecordDoc.getStructureExtMap().get(Content.operative_information);
        if (leaveDiagList != null && leaveDiagList.size() != 0) {
            leaveDiagList.stream().filter(diagMap -> StringUtil.isNotEmpty(diagMap.get("诊断名称")) && (diagListWords.contains(diagMap.get("诊断名称")) || diagMap.get("诊断名称").matches(rex))).forEach(diagMap ->
                    diagList.add(diagMap.get("诊断名称")));
        }
        //门急诊诊断
        String outpatientEmergencyDiag = firstPageRecordDoc.getStructureMap().get(Content.outpatientEmergencyDiag);
        if (StringUtil.isNotBlank(outpatientEmergencyDiag) && diagListWords.contains(outpatientEmergencyDiag) && outpatientEmergencyDiag.matches(rex)) {
            diagList.add(outpatientEmergencyDiag);
        }
        //如果疾病集合为空则直接返回
        if (ListUtil.isEmpty(diagList)) {
            return;
        }
        //性别
        String gender = firstPageRecordDoc.getStructureMap().get(Content.gender);

        if (icdCodeList.contains(gender)) {
            status.set("-1");
            return;
        }

    }
}