package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : FIRP03329
 * @Description :  首页出院诊断有【阴道或外（会）阴裂伤】，无手术操作
 * @Author : wsy
 * @Date: 2022-04-15 15:51
 */
@Component
public class FIRP03329 extends QCCatalogue {
    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 1.【病案首页】>>【出院诊断】中含有【阴道或外阴（会阴）裂伤-疾病列表】中的疾病名称任一，有则继续。
         * 2.查证【病案首页】>>所有【手术及操作名称】未填写则提示。
         * 3.查证【病案首页】>>所有【手术及操作名称】中均不含有【阴道或外阴（会阴）裂伤相关手术】，用是否能匹配正则【pdzz--阴道或外阴（会阴）裂伤相关手术】作为判定标准（病历文本举例：“外阴裂伤缝合术”“外阴缝合”），不能匹配则提示。
         * */
        status.set("0");
        //阴道或外阴（会阴）裂伤-疾病列表
        List<String> diagListWords = Content.JBLB_HYLS;
        //阴道或外阴（会阴）裂伤相关手术
        List<String> diagOpListWords = Content.OP_HYLS;
        //获取病案首页
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        if (firstPageRecordDoc == null) {
            return;
        }
        //匹配疾病正则
        String rex = Content.PDZZ_HYLS;
        //匹配疾病相关手术正则
        String OPRex = Content.PDZZ_HYLSOP;
        //创建存储能匹配疾病的集合
        List<String> diagList = new ArrayList<>();
        //创建存储能匹配疾病手术的集合
        List<String> diagOPList = new ArrayList<>();
        //获取病案首页疾病并判断
        //获取出院诊断
        List<Map<String, String>> leaveDiagList = (List) firstPageRecordDoc.getStructureExtMap().get(Content.operative_information);
        if (leaveDiagList == null || leaveDiagList.size() == 0) {
            return;
        }
        leaveDiagList.stream().filter(diagMap -> StringUtil.isNotEmpty(diagMap.get("诊断名称")) && (diagListWords.contains(diagMap.get("诊断名称")) || diagMap.get("诊断名称").matches(rex))).forEach(diagMap ->
                diagList.add(diagMap.get("诊断名称")));
        //如果疾病集合为空则直接返回
        if (ListUtil.isEmpty(diagList)) {
            return;
        }

        //获取手术信息
        List<Map<String, String>> opList = (List) firstPageRecordDoc.getStructureExtMap().get(Content.operative_information);
        if (opList == null || opList.size() == 0) {
            status.set("-1");
            return;
        }
        opList.stream().filter(diagMap -> StringUtil.isNotEmpty(diagMap.get("手术名称")) && (diagOpListWords.contains(diagMap.get("手术名称")) || diagMap.get("手术名称").matches(OPRex))).forEach(diagMap ->
                diagOPList.add(diagMap.get("手术名称")));

        //如果疾病手术集合为空则直接返回
        if (ListUtil.isEmpty(diagOPList)) {
            status.set("-1");
            return;
        }
    }
}