package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.entity.Operation;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * @ClassName : FIRP03333
 * @Description :  入院记录既往史中有子宫瘢痕性手术史，首页门诊诊断无妊娠合并子宫瘢痕诊断
 * @Author : wsy
 * @Date: 2022-04-15 15:51
 */
@Component
public class FIRP03333 extends QCCatalogue {
    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         *入院记录和病案首页，其中任意一个文书不存在则通过。
         * 1.查证【入院记录】>>【既往史】中，是否有【子宫瘢痕相关手术史】描述，通过能否匹配正则【pdzz--既往史是否有子宫瘢痕相关手术史正则】判定（病历举例：“曾行剖宫产”“剖宫产”“剖腹产”“子宫*术”“子宫*切”“子宫*摘除”）。有则继续。
         * 2.查证【病案首页】>>【门急诊诊断】或【门（急)诊诊断】或【门诊诊断】中是否有诊断能匹配【妊娠合并子宫瘢痕/妊娠合并子宫疤痕/剖宫产瘢痕妊娠/子宫瘢痕处妊娠/剖宫产史的妊娠/妊娠合并宫颈瘢痕】中任一疾病名称，或能匹配正则【pdzz--是否妊娠合并子宫瘢痕的正则】，否则提示。
         * */
        status.set("0");
        //子宫瘢痕相关手术史
        List<String> OPListWords = Content.JBLB_ZGBHOP;
        //妊娠合并子宫瘢痕
        List<String> diagListWords = Content.JBLB_RZZGBH;
        //获取入院记录
        BeHospitalizedDoc beHospitalizedDoc = inputInfo.getBeHospitalizedDoc();
        //获取病案首页
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        if (beHospitalizedDoc == null && firstPageRecordDoc == null) {
            return;
        }
        //匹配既往史是否有子宫瘢痕相关手术史正则
        String OPRex = Content.PDZZ_ZGBHOP;
        //匹配是否妊娠合并子宫瘢痕的正则
        String rex = Content.PDZZ_RZZGBH;
        //创建存储能匹配手术的集合
        List<String> OPList = new ArrayList<>();
        //入院记录不为空，获取既往史
        if (beHospitalizedDoc != null) {
            //既往史
            PastLabel pastLabel = beHospitalizedDoc.getPastLabel();
            if (pastLabel != null) {
                List<Operation> operations = pastLabel.getOperations();
                if (ListUtil.isNotEmpty(operations)) {
                    operations.stream().filter(OP -> StringUtil.isNotEmpty(OP.getName()) && (OPListWords.contains(OP.getName()) || OP.getName().matches(OPRex))).forEach(OP ->
                            OPList.add(OP.getName()));
                }
            }
        }
        //如果手术集合为空则直接返回
        if (ListUtil.isEmpty(OPList)) {
            return;
        }

        //获取病案首页疾病并判断
        if (firstPageRecordDoc != null) {
            //获取门急诊诊断
            String outpatientEmergencyDiagStr = firstPageRecordDoc.getStructureMap().get(Content.outpatientEmergencyDiag);
            if (StringUtil.isNotEmpty(outpatientEmergencyDiagStr) || (!diagListWords.contains(outpatientEmergencyDiagStr) && !outpatientEmergencyDiagStr.matches(rex))) {
                status.set("-1");
                return;
            }
        }
    }
}