package com.lantone.qc.kernel.catalogue.leavehospital;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.client.SimilarityServiceClient;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.doc.LeaveHospitalDoc;
import com.lantone.qc.pub.model.entity.Annotation;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.model.label.DiagLabel;
import com.lantone.qc.pub.model.vo.SimilarityVo;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @ClassName : LEA03323
 * @Description : 入院记录或首页诊断为【胎膜早破】，出院小结出院诊断无胎膜早破
 * @Author : Wsy
 * @Date: 2022-04-13 13:54
 */
@Component
public class LEA03323 extends QCCatalogue {
    @Autowired
    SimilarityServiceClient similarityServiceClient;

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * “出院小结/出院记录”需和（入院记录或病案首页）比较，不存在则不报。
         * 1.查证【入院记录】>>【初步诊断】或【补充诊断】或【修正诊断】，或【首页】>>【出院诊断】中是否有诊断能匹配【胎膜早破-疾病列表】中的疾病名称，或能匹配正则【pdzz--胎膜早破正则】或包含【胎膜早破】，有则继续，且把能匹配的疾病记存为：【list_A】(可能为1个或多个疾病)
         * 2.查证【出院小结/出院记录】>>【出院诊断】中，是否有任一个疾病和【list_A】中的疾病相同或相似（算法模型计算两个疾病的相似度，大于某个相似阈值即可），否则提示。
         *
         * */
        status.set("0");
        List<String> diagListWords = Content.JBLB_TMZP;
        //获取入院记录
        BeHospitalizedDoc beHospitalizedDoc = inputInfo.getBeHospitalizedDoc();
        //获取病案首页
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        if (beHospitalizedDoc == null && firstPageRecordDoc == null) {
            return;
        }
        Date date = StringUtil.parseDateTime("0");
        //匹配疾病正则
        String rex = Content.PDZZ_TMZP;
        //创建存储能匹配疾病的集合
        List<String> diagList = new ArrayList<>();
        //入院记录不为空，获取其诊断信息
        if (beHospitalizedDoc != null) {
            //初步诊断
            DiagLabel initialDiagLabel = beHospitalizedDoc.getInitialDiagLabel();
            //修正诊断
            DiagLabel revisedDiagLabel = beHospitalizedDoc.getRevisedDiagLabel();
            //补充诊断
            DiagLabel suppleDiagLabel = beHospitalizedDoc.getSuppleDiagLabel();
            if (initialDiagLabel != null) {
                List<Diag> diagLists = initialDiagLabel.getDiags();
                if (ListUtil.isNotEmpty(diagLists)) {
                    diagLists.stream().filter(diag -> StringUtil.isNotEmpty(diag.getHospitalDiagName()) && (diagListWords.contains(diag.getHospitalDiagName()) || diag.getHospitalDiagName().matches(rex))).forEach(diag ->
                            diagList.add(diag.getHospitalDiagName()));
                }

            }
            if (revisedDiagLabel != null) {
                List<Diag> diagLists = revisedDiagLabel.getDiags();
                if (ListUtil.isNotEmpty(diagLists)) {
                    diagLists.stream().filter(diag -> StringUtil.isNotEmpty(diag.getHospitalDiagName()) && (diagListWords.contains(diag.getHospitalDiagName()) || diag.getHospitalDiagName().matches(rex))).forEach(diag ->
                            diagList.add(diag.getHospitalDiagName()));
                }
            }
            if (suppleDiagLabel != null) {
                List<Diag> diagLists = suppleDiagLabel.getDiags();
                if (ListUtil.isNotEmpty(diagLists)) {
                    diagLists.stream().filter(diag -> StringUtil.isNotEmpty(diag.getHospitalDiagName()) && (diagListWords.contains(diag.getHospitalDiagName()) || diag.getHospitalDiagName().matches(rex))).forEach(diag ->
                            diagList.add(diag.getHospitalDiagName()));
                }
            }
        }
        //获取病案首页疾病并判断
        if (firstPageRecordDoc != null) {
            //获取出院诊断
            String leaveDiagStr = firstPageRecordDoc.getStructureMap().get("出院诊断");
            if (StringUtil.isNotEmpty(leaveDiagStr)) {
                List<Map<String, String>> leaveDiagList = (List<Map<String, String>>) JSONArray.parse(leaveDiagStr);
                leaveDiagList.stream().filter(diagMap -> StringUtil.isNotEmpty(diagMap.get("诊断名称")) && (diagListWords.contains(diagMap.get("诊断名称")) || diagMap.get("诊断名称").matches(rex))).forEach(diagMap ->
                        diagList.add(diagMap.get("诊断名称")));
            }
        }
        //如果疾病集合为空则直接返回
        if (ListUtil.isEmpty(diagList)) {
            return;
        }
        List<String> diagCollectList = diagList.stream().distinct().collect(Collectors.toList());
        if (ListUtil.isNotEmpty(diagCollectList)) {
            status.set("-1");
            //获取出院小结
            LeaveHospitalDoc leaveHospitalDoc = inputInfo.getLeaveHospitalDoc();
            if (leaveHospitalDoc == null) {
                return;
            }
            //获取入院诊断
            DiagLabel beHospitalizedLabel = leaveHospitalDoc.getBeHospitalizedLabel();
            if (beHospitalizedLabel == null) {
                return;
            }
            List<Diag> diags = beHospitalizedLabel.getDiags();
            if (ListUtil.isEmpty(diags)) {
                return;
            }
            for (Diag diag : diags) {
                String diagName = diag.getHospitalDiagName();
                for (String diagCollectName : diagCollectList) {
                    if (StringUtil.isNotEmpty(diagName) && StringUtil.isNotEmpty(diagCollectName)) {
                        if (getLikeRate(diagName, diagCollectName)) {
                            status.set("0");
                            return;
                        }
                    }
                }
            }
            return;
        }
    }

    private boolean getLikeRate(String text_1, String text_2) {
        JSONArray similarContent = new JSONArray();
        JSONObject detailContent = new JSONObject();
        detailContent.put("text_1", text_1);
        detailContent.put("text_2", text_2);
        similarContent.add(detailContent);
        //存储CRF完整所需结构数据
        SimilarityVo similarityVo = new SimilarityVo();
        similarityVo.setData(similarContent);
        //获取CRF模型返回数据
        JSONArray data = getAnnotation(similarityServiceClient, similarityVo).getData();
        double likeRate = 0d;
        if (data.size() > 0) {
            JSONObject dataContent = data.getJSONObject(0);
            likeRate = dataContent.getDoubleValue("like_rate");
        }
        if (likeRate > 0.9) {
            return true;
        }
        return false;
    }

    private Annotation getAnnotation(SimilarityServiceClient similarityServiceClient, SimilarityVo similarityVo) {
        Annotation annotation = new Annotation();
        try {
            String annotation_str = similarityServiceClient.getAnnotation(similarityVo);
            annotation = JSON.parseObject(annotation_str, Annotation.class);
        } catch (Exception ex) {
            ex.printStackTrace();
        } finally {
            return annotation;
        }
    }
}
