package com.lantone.qc.kernel.catalogue.preoperativediscussion;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @ClassName : PRE03306
 * @Description :  产科检查中破膜未破与胎膜早破诊断不符
 * @Author : 尤伟豪
 * @Date: 2022/4/18 17:19
 */

/*1.查证【术前讨论】>>【简要病情】或【*病情*】或【*查体*】或【*产科检查*】字段内容中有能匹配正则【pdzz--破膜未破描述正则】，有则继续。
        2.查证【病案首页】或【出院小结】>>【出院诊断】中是否有诊断能匹配【胎膜早破-疾病列表】中任一疾病名称
        ，或有任一能匹配正则【pdzz--胎膜早破正则】，则提示。*/
@Component
public class PRE03306 extends QCCatalogue {

    //破膜未破正则匹配
    public static boolean getCompile(String i){

        String regex = "(?<!([未否无没不非]|排除)[^。，；｡,;]{0,20})[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:(?:胎膜)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:未破|未见破|没有破|没破)|(?:没破膜|未破膜))(?!([^。，；｡,;]{0,3}([:：\t](否|无|从不|从未|未发现|未见|未诉|没有)|(否|无|从不|从未|未发现|未见|未诉|没有)(\\b|[。，；｡,;\f\n\r\t]))))";
        Pattern pattern = Pattern.compile(regex);
        Matcher matcher= pattern.matcher(i);
        if (matcher.find()){
            return true;
        }
        return false;


    }
    //破膜破了正则匹配
    public static boolean getIsCompile(String physical){

        String regex = "(?<!([未否无没不非]|排除)[^。，；｡,;]{0,20})[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:(?:胎膜)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:早破|早期破裂))(?!([^。，；｡,;]{0,3}([:：\\t](否|无|从不|从未|未发现|未见|未诉|没有)|(否|无|从不|从未|未发现|未见|未诉|没有)(\\\\b|[。，；｡,;\\f\\n\\r\\t]))))";
        Boolean i = false;
        Pattern pattern = Pattern.compile(regex);
        Matcher matcher= pattern.matcher(physical);
        if (matcher.find()){
            i = true;
        }
        return i;

    }


    public void start(InputInfo inputInfo, OutputInfo outputInfo) {

        status.set("0");
        //将手术有关信息用list集合储存
        List<OperationDoc> operationDocList = inputInfo.getOperationDocs();
        boolean f =false;
        //增强for循环遍历集合中的每个元素
        for(OperationDoc operationDoc : operationDocList){
            if(operationDoc == null){
                return;
            }
            //判断手术字段中的术前讨论信息是否为空
            if(operationDoc.getPreoperativeDiscussionDoc() == null){
                return;
            }
            //定义术前讨论中的先关字段
            String a = operationDoc.getPreoperativeDiscussionDoc().getStructureMap().get("简要病情");
            String b = operationDoc.getPreoperativeDiscussionDoc().getStructureMap().get("*病情*");
            String c = operationDoc.getPreoperativeDiscussionDoc().getStructureMap().get("*查体*");
            String d = operationDoc.getPreoperativeDiscussionDoc().getStructureMap().get("*产科检查*");
            if(StringUtil.isNotBlank(a) && getCompile(a) || StringUtil.isNotBlank(b) && getCompile(b)
                    || StringUtil.isNotBlank(c) && getCompile(c)|| StringUtil.isNotBlank(d) && getCompile(d)
            ){
                 f = true;
                 break;
            }
        }
        if(f){
            //建立一个list集合来存储相关疾病
            List<String> disease_name = Arrays.asList("胎膜早破", "足月胎膜早破", "早产胎膜早破");
            //.查证【病案首页】中出院诊断中是否是否有诊断能匹配【胎膜早破-疾病列表】中任一疾病名称，或有任一能匹配正则【pdzz--胎膜早破正则】，则提示。
            if(inputInfo.getFirstPageRecordDoc() != null) {
                String h = "";
                //注意病案首页返回类型为map集合
                Map<String, Object> firstpageStructureMap = inputInfo.getFirstPageRecordDoc().getStructureExtMap();
                //病案首页中的出院诊断集合
                List<Map<String, String>> dischargeDiag = (List) firstpageStructureMap.get(Content.dischargeDiag);
                if (ListUtil.isEmpty(dischargeDiag)) {
                    return;
                }
                //取出map集合里的相应字符串
                for (Map<String, String> diagMap : dischargeDiag) {
                    h = diagMap.get("诊断名称");
                    for (int i = 0; i < disease_name.size(); i++) {
                        String name = disease_name.get(i);
                        //判断病案首页中的出院诊断字段中的诊断名称是否有匹配胎膜早破-疾病列表中任一疾病名称
                        if (StringUtil.isNotBlank(h) && h.contains(name)) {
                            status.set("1");
                            return;
                        }
                    }
                    //判断是否匹配早破正则
                    if (getIsCompile(h)) {
                        status.set("1");
                        return;
                    }
                }
            }
            //.查证出院小结中出院诊断中是否是否有诊断能匹配【胎膜早破-疾病列表】中任一疾病名称，或有任一能匹配正则【pdzz--胎膜早破正则】，则提示。
            if(inputInfo.getLeaveHospitalDoc() != null){
                String k = inputInfo.getLeaveHospitalDoc().getStructureMap().get("出院诊断");

                for (int i = 0; i < disease_name.size(); i++) {
                    String name = disease_name.get(i);
                    //出院小结中的出院诊断字段是否有匹配胎膜早破-疾病列表中任一疾病名称
                    if (StringUtil.isNotBlank(k) && k.contains(name) ) {
                        status.set("1");
                        return;
                    }
                }
                //判断是否匹配早破正则
                if (getIsCompile(k)) {
                    status.set("1");
                    return;
                }
            }



        }



    }



}