package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @ClassName : THR03304
 * @Description :  产科检查中破膜未破与胎膜早破诊断不符
 * @Author : 尤伟豪
 * @Date: 2022/4/18 10:11
 */

/*1.查证【查房记录】>>有任一能匹配正则【pdzz--破膜未破描述正则】，有则继续。
        2.查证【入院记录】>>【初步诊断】或【补充诊断】或【修正诊断】中是否有诊断能匹配【胎膜早破-疾病列表】中任一疾病名称，
        或有任一能匹配正则【pdzz--胎膜早破正则】，则提示。*/
@Component
public class THR03304 extends QCCatalogue {

    //破膜未破正则匹配
    public static boolean getCompile(String i){

        String regex = "(?<!([未否无没不非]|排除)[^。，；｡,;]{0,20})[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:(?:胎膜)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:未破|未见破|没有破|没破)|(?:没破膜|未破膜))(?!([^。，；｡,;]{0,3}([:：\t](否|无|从不|从未|未发现|未见|未诉|没有)|(否|无|从不|从未|未发现|未见|未诉|没有)(\\b|[。，；｡,;\f\n\r\t]))))";
        Pattern pattern = Pattern.compile(regex);
        Matcher matcher= pattern.matcher(i);
        if (matcher.find()){
            return true;
        }
        return false;


    }
    //破膜破了正则匹配
    public static boolean getIsCompile(String physical){

        String regex = "(?<!([未否无没不非]|排除)[^。，；｡,;]{0,20})[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:(?:胎膜)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:早破|早期破裂))(?!([^。，；｡,;]{0,3}([:：\\t](否|无|从不|从未|未发现|未见|未诉|没有)|(否|无|从不|从未|未发现|未见|未诉|没有)(\\\\b|[。，；｡,;\\f\\n\\r\\t]))))";
        Boolean i = false;
        Pattern pattern = Pattern.compile(regex);
        Matcher matcher= pattern.matcher(physical);
        if (matcher.find()){
            i = true;
        }
        return i;

    }


    public void start(InputInfo inputInfo, OutputInfo outputInfo) {

        status.set("0");

        if(inputInfo.getThreeLevelWardDocs() == null){
            return;
        }
        //获取查房记录集合
        List<ThreeLevelWardDoc> threeLevel = inputInfo.getThreeLevelWardDocs();
        if(threeLevel.get(0).getAllDoctorWradDocs() == null){
            return;
        }
        //获取查房记录中的所有查房记录
        List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevel.get(0).getAllDoctorWradDocs();
        boolean f =false;
        //增强for循环遍历集合中的每个元素
        for(ThreeLevelWardDoc three : allDoctorWradDocs){
                //获取所有查房记录集合中的病情记录
                String a = three.getStructureMap().get("病情记录");
                //判断查房记录中的病情记录字段是否匹配正则，有则返回true,继续
                if(StringUtil.isNotBlank(a) && getCompile(a)){
                    f = true;
                    break;
                }

        }

        if(f){
            if(inputInfo.getBeHospitalizedDoc() == null){
                return;
            }
            String b = inputInfo.getBeHospitalizedDoc().getStructureMap().get("初步症断");
            String c = inputInfo.getBeHospitalizedDoc().getStructureMap().get("补充症断");
            String d = inputInfo.getBeHospitalizedDoc().getStructureMap().get("修正症断");
            //建立一个list集合来存储相关疾病
            List<String> disease_name = Arrays.asList("胎膜早破","足月胎膜早破","早产胎膜早破");
            //遍历每个疾病并与入院记录中的各个字段相匹配
           for(int i=0;i < disease_name.size();i++){
               String name = disease_name.get(i);
               if(StringUtil.isNotBlank(b) && b.contains(name) || StringUtil.isNotBlank(c)
                       && c.contains(name) || StringUtil.isNotBlank(d) && d.contains(name)){
                   status.set("1");
                   return;
               }
           }
            //匹配到胎膜早破正则,输出，
            if(StringUtil.isNotBlank(b) &&getIsCompile(b) || StringUtil.isNotBlank(b) &&getIsCompile(c) || StringUtil.isNotBlank(b) &&getIsCompile(d)){
                status.set("1");
                return;
            }

        }



    }



}