package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.util.ListUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @ClassName : THR03309
 * @Description :  首页诊断有外（会）阴裂伤，但产时记录中无相关描述
 * @Author : 尤伟豪
 * @Date: 2022/4/19 14:24
 */

/*1.查证【首页】>>【出院诊断】中是否有诊断能匹配【阴道或外（会）阴裂伤-疾病列表】中的疾病名称，或诊断能匹配正则【pdzz--外阴（会阴）裂伤】（参见正则列表），有则继续
        2.查证【查房记录中】均不含有【产时外阴（会阴）裂伤相关描述】，
        用是否能匹配正则【pdzz--产时外阴（会阴）裂伤相关描述】作为判定标准
        （病历文本举例：“产时外阴裂伤”“分娩时外阴裂伤”“分娩时*阴道轻度裂伤”“分娩时*外阴二度裂伤*已行缝合处理”），不能匹配则提示。*/
@Component
public class THR03309 extends QCCatalogue {

    //外阴（会阴）裂伤
    public static boolean getCompile(String i){

        String regex = "(?<!([未否无没不非]|排除)[^。，；｡,;]{0,20})[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:(?:会阴|外阴|阴道)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:裂伤|破裂|挫裂|撕裂))(?!([^。，；｡,;]{0,3}([:：\\t](否|无|从不|从未|未发现|未见|未诉|没有)|(否|无|从不|从未|未发现|未见|未诉|没有)(\\\\b|[。，；｡,;\\f\\n\\r\\t]))))";
        Pattern pattern = Pattern.compile(regex);
        Matcher matcher= pattern.matcher(i);
        if (matcher.find()){
            return true;
        }
        return false;


    }
    //外阴（会阴）裂伤相关描述
    public static boolean getIsCompile(String physical){

        String regex = "(?<!([未否无没不非]|排除)[^。，；｡,;]{0,20})[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:(?:产时|分娩|娩时|产程|产中)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:会阴|外阴|阴道)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:裂伤|破裂|挫裂|撕裂)|(?:会阴|外阴|阴道)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:产时|分娩|娩时|产程|产中)[^。，；｡,;未否无没不非]{0,10}(未知|未明|淹没|没药|不对称|非对称)?[^。，；｡,;未否无没不非]{0,10}(?:裂伤|破裂|挫裂|撕裂))(?!([^。，；｡,;]{0,3}([:：\\t](否|无|从不|从未|未发现|未见|未诉|没有)|(否|无|从不|从未|未发现|未见|未诉|没有)(\\\\b|[。，；｡,;\\f\\n\\r\\t]))))";
        Pattern pattern = Pattern.compile(regex);
        Matcher matcher= pattern.matcher(physical);
        if (matcher.find()){
           return true;
        }
        return false;

    }


    public void start(InputInfo inputInfo, OutputInfo outputInfo) {

        status.set("0");
        //建立一个list集合来存储阴道或外（会）阴裂伤-疾病列表】中的疾病名称
        List<String> disease_name = Content.JBLB_HYLS;

        Map<String, Object> firstpageStructureMap = inputInfo.getFirstPageRecordDoc().getStructureExtMap();
        List<Map<String, String>> dischargeDiag = (List) firstpageStructureMap.get(Content.dischargeDiag);
        if (ListUtil.isEmpty(dischargeDiag)) {
            return;
        }
        for (Map<String, String> diagMap : dischargeDiag) {
            //获取出院诊断中的诊断名称
            String h = diagMap.get("诊断名称");
            boolean k = false;
            for (int i = 0; i < disease_name.size(); i++) {
                String name = disease_name.get(i);
                //查证诊断名称是否匹配疾病列表任一疾病，有则获取入院病情这个字段，用于接下来的规则匹配
                if (h != null) {
                    if (h.contains(name) || getCompile(h)) {
                        k = true;
                    }
                    if (k) {

                        if(inputInfo.getThreeLevelWardDocs() == null){
                            return;
                        }
                        //获取查房记录集合
                        List<ThreeLevelWardDoc> threeLevel = inputInfo.getThreeLevelWardDocs();
                        if(threeLevel.get(0).getAllDoctorWradDocs() == null){
                            return;
                        }
                        //获取查房记录中的所有查房记录
                        List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevel.get(0).getAllDoctorWradDocs();
                        //增强for循环遍历集合中的每个元素
                        for(ThreeLevelWardDoc three : allDoctorWradDocs){
                            //获取所有查房记录集合中的病情记录
                            String a = three.getStructureMap().get("病情记录");
                            //判断查房记录中的病情记录字段是否匹配正则，有则返回true,继续
                            if(!getIsCompile(a)){
                                status.set("1");
                                return;


                            }

                        }

                    }
                }

            }

        }
    }



}