package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.model.entity.Fertility;
import com.lantone.qc.pub.model.label.DiagLabel;
import com.lantone.qc.pub.model.label.MaritalLabel;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;


/**
 * @ClassName : THR03325
 * @Description : 查房记录中孕产次描述应与婚育史中孕产次符合
 * @Author : wsy
 * @Date: 2022-04-19 17:28
 */
@Component
public class THR03325 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 1.查证【查房记录】中的孕产次（怀孕次数和生产次数，真实诊断名称举例：“孕2产1孕40周LOA待产”“G2P1”，均表示目前怀孕2次，生产1次）。所有查房记录内容逐个去匹配正则【[Gg孕][^1-9]?([1-9])[^1-9]?[Pp产][^1-9]?([0-9])[^1-9]】，成功匹配后，捕获的匹配组1的数字字符记为【孕次A】，捕获的匹配组2的数字字符记为【产次B】，没有诊断能匹配则直接返回。
         * 2.查证【入院记录】>>【婚育史】或【生育史】中【孕产次】（最常见真实病历举例：“1-0-0-1”，表示目前为止：足月产1次，早产0次，流产0次，现存子女数1个，前三个数字想加记为总产次，如果本次住院又怀孕了，肚子里的暂时还没生产，所以总孕次为：总产次+1）。查证和提取方法：【婚育史】或【生育史】内容能匹配正则【([0-9])-([0-9])-([0-9])-([0-9])】，则说明记录了孕产次，并以此提取四个数字符号为【“a”“b”“c”“d”】，那么产次为：a+b+c，孕次为：a+b+c+1（上面一步证明患者本次又怀孕了）。
         * 3.判断：孕次A==a+b+c+1，且产次B==a+b+c，则通过，否则提示（说明：碰到其它医院不同写法时，理解每个数字的意思后，需另外写针对医院的个性化提取逻辑或代码）
         * */
        status.set("0");
        List<String> diagListWords = Content.JBLB_YCC;
        //获取入院记录
        BeHospitalizedDoc beHospitalizedDoc = inputInfo.getBeHospitalizedDoc();
        List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
        if (beHospitalizedDoc == null || threeLevelWardDocs == null) {
            return;
        }
        //创建存储能匹配疾病的集合
        List<String> diagList = new ArrayList<>();
        //存放孕次A
        String graNum = "";
        //存放产次B
        String parityNum = "";
        //查房记录不为空，获取孕产次
        ThreeLevelWardDoc threeLevelWardDoc = threeLevelWardDocs.get(0);
        List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDoc.getAllDoctorWradDocs();
        for (ThreeLevelWardDoc threeLevelWard : allDoctorWradDocs) {
            Map<String, String> structureMap = threeLevelWard.getStructureMap();
            String record = structureMap.get("病情记录");
            Pattern pattern = Pattern.compile("[Gg孕][^1-9]?([1-9])[^1-9]?[Pp产][^1-9]?([0-9])[^1-9]");
            Matcher matcher = pattern.matcher(record);
            if (matcher.find()) {
                diagList.add(matcher.group());
            }
        }
        //如果疾病集合为空则直接返回
        if (ListUtil.isEmpty(diagList)) {
            return;
        }

        if (diagList.get(0).contains("孕")) {
            graNum = diagList.get(0).substring(diagList.get(0).indexOf("孕"), Math.min(diagList.get(0).length(), diagList.get(0).indexOf("孕") + 1));
        }
        if (diagList.get(0).contains("产")) {
            parityNum = diagList.get(0).substring(diagList.get(0).indexOf("产"), Math.min(diagList.get(0).length(), diagList.get(0).indexOf("产") + 1));
        }

        if (StringUtil.isEmpty(graNum) || StringUtil.isEmpty(parityNum)) {
            return;
        }

        //获取入院记录婚育史中孕产次
        String PPT = "";
        //获取婚育史
        MaritalLabel maritalLabel = beHospitalizedDoc.getMaritalLabel();
        if (maritalLabel == null) {
            return;
        }

        Fertility fertility = maritalLabel.getFertility();
        if (fertility == null) {
            return;
        }
        String name = fertility.getName();
        Pattern p = Pattern.compile("([0-9])-([0-9])-([0-9])-([0-9])");
        Matcher matcher = p.matcher(name);
        if (matcher.find()) {
            PPT = matcher.group();
        }
        if (StringUtil.isEmpty(PPT)) {
            return;
        }
        //[孕次A】==a+b+c+1，且【产次B】==a+b+c
        String[] split = PPT.split("-");
        try {
            if ((strConvertInt(graNum) != strConvertInt(split[0]) + strConvertInt(split[1]) + strConvertInt(split[2]) + 1) ||
                    (strConvertInt(parityNum) != strConvertInt(split[0]) + strConvertInt(split[1]) + strConvertInt(split[2]))
            ) {
                status.set("-1");
                return;
            }
        } catch (Exception e) {
            return;
        }
    }

    //String转int
    private int strConvertInt(String str) {
        return Integer.parseInt(str);
    }
}