package com.lantone.qc.trans.changshaxy.util;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @author: rengb
 * @time: 2020/9/15 16:28
 */
@Slf4j
public class XyBeHospitalizedHtmlAnalysis implements XyHtmlAnalysis {

    private String modeId = "1";

    @Override
    public Map<String, String> analysis(String... args) {
        Map<String, String> map = Maps.newLinkedHashMap();
        try {
            String html = args[0];
            String recTitle = args[1];
            String recTypeId = args[2];
            Document doc = Jsoup.parse(html);

            if (recTitle.contains("24")) {
                analysis24h(doc, map);
            } else if (recTitle.contains("日间病历")) {
                analysisDay(doc, map);
            } else {
                analysisGeneral(doc, recTitle, map);
            }
            XyHtmlAnalysisUtil.insertModuleId(modeId, recTypeId, map);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return map;
    }

    //一般模板
    private void analysisGeneral(Document doc, String recTitle, Map<String, String> map) {

        String htmlString = XyHtmlAnalysisUtil.blockDivToStr(doc.selectFirst("body"), true)
                .replace("&nbsp", ":")
                .replace("8220","“")
                .replace("8221","”");

        List<String> titles = Lists.newArrayList("姓名", "出生地", "性别", "民族", "年龄", "职业", "婚姻", "病史陈述者",
                "入院日期", "入院时间", "病历记录时间", "住址", "联系电话",
                "入院方式", "主诉", "现病史", "既往史", "个人史", "婚育史", "月经史", "家族史",
                "初步诊断", "入院诊断", "体 格 检 查", "体 格 检 查 ", "专科情况", "辅助检查", "入院诊断", "医师", "上级医师", "签字时间");
        titles = CommonAnalysisUtil.sortTitles(titles, htmlString);
        CommonAnalysisUtil.cutByTitles(htmlString, titles, 0, map);

        //家族史其中可能包括体格检查
        if (StringUtil.isNotBlank(map.get("家族史"))) {
            map.put("家族史",map.get("家族史").replace(":", ""));
        }
        if (StringUtils.isNotEmpty(map.get("家族史"))){
//            if (map.get("家族史").contains("体 格 检 查 ")) {
//                Integer index = map.get("家族史").indexOf("体 格 检 查 ");
//                map.put("体格检查", map.get("家族史").substring(index + "体 格 检 查 ".length(), map.get("家族史").length()));
//                map.put("家族史", map.get("家族史").substring(0, index));
//            }
            if (map.get("家族史").contains("体 格 检 查")) {
                Integer index = map.get("家族史").indexOf("体 格 检 查");
                map.put("体格检查", map.get("家族史").substring(index + "体 格 检 查".length(), map.get("家族史").length()));
                map.put("家族史", map.get("家族史").substring(0, index));
            }
        }

        if (StringUtils.isNotEmpty(map.get("体格检查"))){
            String str =map.get("体格检查");
            str = str.replace("神 经 系 统 检 查","神经系统检查: ").replace("浅 感 觉 检 查 记 录 图","浅感觉检查记录:");
            List<String> titlestr = Lists.newArrayList("神经系统检查","运动系统","浅感觉检查记录","感觉系统","自主神经系统");
            titlestr = CommonAnalysisUtil.sortTitles(titlestr, str);
            CommonAnalysisUtil.cutByTitles(str, titlestr, 0, map);
        }

        if (StringUtils.isEmpty(map.get("专科情况"))){
            map.put("专科情况","神经系统检查："+map.get("神经系统检查")+"\n运动系统："+map.get("运动系统")+"\n浅感觉检查记录："+
                    map.get("浅感觉检查记录")+"\n感觉系统："+map.get("感觉系统")+"\n自主神经系统："+map.get("自主神经系统"));
        }
    }

    //24小时出入院记录、24小时出入院记录（全院）、24小时入出院记录(全院通用)、24小时内入院死亡记录(全院通用)
    private void analysis24h(Document doc, Map<String, String> map) {
        String text = XyHtmlAnalysisUtil.blockDivToStr(doc.selectFirst("body").child(0), false);
        text = text.substring(text.lastIndexOf("24小时入出院记录姓    名")).replaceFirst("第1页", "");
        List<String> titles = Lists.newArrayList("姓    名", "家庭住址", "性    别", "工作单位", "年    龄", "身份证号码", "民    族",
                "联系人(关系)", "职    业", "入院时间", "婚    姻", "死亡时间", "记录时间", "出 生 地", "病史陈述者", "主    诉", "入院情况", "心理评估",
                "疼痛评估", "营养评估", "功能评估", "入院诊断", "诊疗经过", "死亡原因", "死亡诊断", "出院情况", "出院诊断", "出院计划", "出院医嘱",
                "出院去向", "医师签名", "书写时间");

        CommonAnalysisUtil.cutByTitles(text, titles, 0, map);
        CommonAnalysisUtil.processType(map, "出院去向");
    }

    //原-日间病历入出院记录、日间病历-性早熟
    private void analysisDay(Document doc, Map<String, String> map) {
        //个人基础信息table解析
        XyHtmlAnalysisUtil.tableStyle1InsertMap(doc.getElementById("table1"), map);
        //主诉、入院情况等table解析
        XyHtmlAnalysisUtil.tableStyle2InsertMap(doc.getElementById("table6"), map);
        //医生签名、医生签名时间
        Element docSignElement = null, docSignTimeElement = null;
        for (Element table6ElementNt : doc.getElementById("table6").parent().nextElementSiblings()) {
            docSignElement = table6ElementNt.selectFirst("image,img");
            if (docSignElement != null) {
                docSignTimeElement = table6ElementNt.nextElementSibling();
                break;
            }
        }
        if (docSignElement != null) {
//            map.put("医生签名", docSignElement.outerHtml());
            map.put("医生签名", "暂无");
        }
        if (docSignTimeElement != null) {
            map.put("医生签名时间", XyHtmlAnalysisUtil.elementLayer1ToStr(docSignTimeElement, false).trim());
        }
    }

    private void disHandleExt(Map<String, String> map) {
        String[] keys = {"中医诊断", "西医诊断"};
        String value = null;
        int index = 0;
        for (String key : keys) {
            value = map.get(key);
            if (StringUtil.isNotBlank(value)) {
                for (String key_ : keys) {
                    index = value.indexOf(key_);
                    if (index > 0) {
                        map.put(key_, value.substring(index + 5));
                        map.put(key, value.substring(0, index));
                    }
                }
            }
        }
    }

}