package com.lantone.qc.trans.changshaxy.util;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import lombok.extern.slf4j.Slf4j;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;

import java.util.List;
import java.util.Map;

/**
 * @Description: 疑难、危重病例讨论记录html解析
 * @author: HUJING
 * @time: 2020/9/14 15:41
 */
@Slf4j
public class XyDifficultCaseDiscussHtmlAnalysis implements XyHtmlAnalysis {

    private String modeId = "19";

    @Override
    public Map<String, String> analysis(String... args) {
        Map<String, String> structureMap = Maps.newLinkedHashMap();
        try {
            List<String> titles = Lists.newArrayList("时间", "地点", "参加人员", "主持人", "病例报告人",
                    "病历摘要","入院诊断","入院查体","查体","体查", "辅助检查","诊疗经过：", "发言人", "总结意见","主持人", "记录人");
            String html = args[0];
            String recTitle = args[1];
            String recTypeId = args[2];
            Document doc = Jsoup.parse(html);
            String htmlContent = XyHtmlAnalysisUtil.blockDivToStr(doc.selectFirst("body"), true).replace("&nbsp", ":");
            if (StringUtil.isNotBlank(htmlContent)) {
                htmlContent = htmlContent.replaceAll("[   ]", " ").replace("第一页", "").replace("发言记录（包括病史简要、讨论意见及结论）：", "");
                CommonAnalysisUtil.html2StructureMap(titles, htmlContent, structureMap);
            }
            CommonAnalysisUtil.extractDateByTitle(structureMap, "告知时间");
            removeLast(structureMap);
            if (structureMap.containsKey("入院诊断")) {
                structureMap.put("病历摘要",structureMap.get("病历摘要")+"入院诊断："+structureMap.get("入院诊断"));
            }else if (structureMap.containsKey("诊断")){
                structureMap.put("病历摘要",structureMap.get("病历摘要")+"入院诊断："+structureMap.get("诊断"));
            }
            XyHtmlAnalysisUtil.insertModuleId(modeId, recTypeId, structureMap);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return structureMap;
    }

    /**
     * 去除value中最后的逗号
     *
     * @param structureMap
     */
    private void removeLast(Map<String, String> structureMap) {
        for (Map.Entry<String, String> entry : structureMap.entrySet()) {
            structureMap.put(entry.getKey(), findLast(entry.getValue()));
        }
    }

    private String findLast(String value) {
        if (StringUtil.isNotBlank(value)) {
            if (value.lastIndexOf("，") != value.length() - 1) {
                return value;
            }
            value = value.substring(0, value.length() - 1);
            findLast(value);
        }
        return value;
    }
}