package com.lantone.qc.trans.changshaxy.util;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.trans.changshaxy.util.comsis.XyCommonAnalysisUtil;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import lombok.extern.slf4j.Slf4j;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Element;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @author: rengb
 * @time: 2020/9/28 16:36
 */
@Slf4j
public class XyOperationRecordHtmlAnalysis implements XyHtmlAnalysis {

    private String modeId = "17";

    @Override
    public Map<String, String> analysis(String... args) {
        Map<String, String> map = Maps.newLinkedHashMap();
        try {
            String html = args[0];
            String recTitle = args[1];
            String recTypeId = args[2];
            Element bigDivElement = Jsoup.parse(html).selectFirst("body").child(0);
            analysisGeneral(bigDivElement, map);
            XyHtmlAnalysisUtil.mapValueRemoveStartColon(map);
            CommonAnalysisUtil.makeEmpty(map, "医生签名");
            XyHtmlAnalysisUtil.insertModuleId(modeId, recTypeId, map);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return map;
    }

    private void analysisGeneral( Element bigDivElement, Map<String, String> map) {
        String text = XyHtmlAnalysisUtil.blockDivToStr(bigDivElement, true);
        text = text.replaceAll("第1页", "")
                .replace("（包括体位、切口处理经过，病灶所见及手术步骤等）：", "");
        List<String> titles = Lists.newArrayList(
                "手术日期", "是否非计划再次手术", "麻醉", "术前诊断", "术后诊断", "拟施手术", "实施手术", "手术级别", "术者", "一助",
                "二助", "手术指导者", "手术过程", "手术医师签名"
        );
        titles = XyCommonAnalysisUtil.sortTitles(titles, text);
        XyCommonAnalysisUtil.cutByTitles(text, titles, 0, map);
        if (map.containsKey("手术医师签名")){
            String name =map.get("手术医师签名");
            String date =XyCommonAnalysisUtil.extractDate(name);
            if (date != null) {
                map.put("签名时间", date);
                name =name.substring(0,name.indexOf(date));
                map.put("手术医师签名",name);
            }
        }
    }

}