package com.lantone.qc.trans.changshaxy.util;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.changshaxy.util.comsis.XyCommonAnalysisUtil;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import lombok.extern.slf4j.Slf4j;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Element;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @author: rengb
 * @time: 2020/9/17 19:19
 */
@Slf4j
public class XyPreoperativeHtmlAnalysis implements XyHtmlAnalysis {

    private String modeId = "11";

    @Override
    public Map<String, String> analysis(String... args) {
        Map<String, String> map = Maps.newLinkedHashMap();
        try {
            String html = args[0];
            String recTitle = args[1];
            String recTypeId = args[2];
            Element bigDivElement = Jsoup.parse(html).selectFirst("body").child(0);
            analysisGeneral(recTitle,bigDivElement, map);

            XyHtmlAnalysisUtil.mapValueRemoveStartColon(map);
            XyHtmlAnalysisUtil.insertModuleId(modeId, recTypeId, map);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return map;
    }

    private void analysisGeneral(String recTitle,Element bigDivElement, Map<String, String> map) {
        /*if (bigDivElement.selectFirst("hr") != null) {
            bigDivElement.selectFirst("hr").previousElementSiblings().remove();
        }*/
        String text = XyHtmlAnalysisUtil.blockDivToStr(bigDivElement, true).replace("·", "").replace("&nbsp"," ");

        XyCommonAnalysisUtil.extractWardInfo(recTitle,text, map);

        List<String> titles = Lists.newArrayList("姓名", "性别", "年龄","病区","床号", "住院号", "讨论日期", "手术者", "第一助手",
                "第二助手","参加讨论者","手术前主要诊断","诊断依据","术后诊断依据","手术条件及准备","手术抉择及指征（拟行手术）",
                "手术计划（切口选择；手术主要步骤；术中可能发生的困难；可能发生的问题及解决方法）","麻醉抉择及注意要点",
                "术后可能发生主要并发症的估计及预防","记录者","手术者签名");
        XyCommonAnalysisUtil.cutByTitles(text, titles, 0, map);
        // 解决医生签名显示 年 月 日 时 分
        signatureTime(map);
    }

    /**
     * 解决医生签名时间显示 年 月 日 时 分
     *
     * @param map
     */
    private void signatureTime(Map<String, String> map) {
        String goCureDoctor = map.get("经治医生签字时间");
        String operateDoctor = map.get("主刀医生签字时间");
        if (StringUtil.isNotBlank(goCureDoctor) && goCureDoctor.contains("年 月 日 时 分")) {
            map.put("经治医生签字时间", goCureDoctor.replace("年 月 日 时 分", ""));
        }
        if (StringUtil.isNotBlank(operateDoctor) && operateDoctor.contains("年 月 日 时 分")) {
            map.put("主刀医生签字时间", operateDoctor.replace("年 月 日 时 分", ""));
        }
    }

}