package com.lantone.qc.trans.yiwu;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.dbanaly.facade.yiwu.YiWuXmlUtil;
import com.lantone.qc.dbanaly.util.ModuleMappingUtil;
import com.lantone.qc.pub.model.doc.DeathCaseDiscussDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.FastJsonUtils;
import com.lantone.qc.pub.util.MapUtil;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import com.lantone.qc.trans.comsis.OrdinaryAssistant;

import java.util.List;
import java.util.Map;

/**
 * @Description: 死亡病例讨论记录文档生成
 * @author: rengb
 * @time: 2020/3/17 13:22
 */
public class YiWuDeathCaseDiscussDocTrans extends ModelDocTrans {
    private String modeId = "3";

    @Override
    public DeathCaseDiscussDoc extract(MedrecVo medrecVo) {
        Map<String, Object> contentMap = ((List<Map>) medrecVo.getContent().get("content")).get(0);
        String content = contentMap.get("xmlText").toString();
        Map<String, String> structureMap = null;
        if (contentMap.get("isParsed") != null && "1".equals(contentMap.get("isParsed").toString())) {
            structureMap = (Map) FastJsonUtils.getJsonToMap(content);
        } else {
            Map<String, String> sourceMap = YiWuXmlUtil.xmlToMap(content);
            sourceMap.put("mode_id", ModuleMappingUtil.getDeptModuleId(modeId));
            sourceMap.put("mode_id=" + contentMap.get("modeId").toString(), "");
            sourceMap.put("rec_title=" + contentMap.get("recTitle").toString(), "");

            Map<String, String> cutMap = Maps.newHashMap();
            String text = sourceMap.get("讨论记录").replace("：", ":");
            List<String> titles = Lists.newArrayList(
                    "八、主持人总结","七：讨论意见","六、诊疗经过(重点记录病情演变，抢救经过)","五、死亡诊断",
                    "四、死亡原因","三、 死亡时间","二、主    诉","一、入院情况");
            List<String> sortTitles = CommonAnalysisUtil.sortTitles(titles, text);
            CommonAnalysisUtil.cutByTitlesNoColon(text, sortTitles, 0, cutMap);

            mapJoin(sourceMap, cutMap);
            structureMap = OrdinaryAssistant.mapKeyContrast(sourceMap, keyContrasts, modeId);

        }

        MapUtil.keyAssig(structureMap, "参加讨论人员", "参加人员及职称医生", "参加人员及职称");
        DeathCaseDiscussDoc deathCaseDiscussDoc = new DeathCaseDiscussDoc();
        deathCaseDiscussDoc.setStructureMap(structureMap);
        deathCaseDiscussDoc.setPageData((Map) structureMap);

        return deathCaseDiscussDoc;
    }

    private void mapJoin(Map<String, String> sourceMap, Map<String, String> dailyTrans) {
        dailyTrans.forEach((k, v) -> {
            if (!sourceMap.containsKey(k)) {
                sourceMap.put(k, v);
            }
        });
    }

    private List<String> keyContrasts = Lists.newArrayList(
            "主持人姓名=讨论主持人",
            "死亡日期=死亡时间",
            "讨论意见=讨论内容",
            "记录医师=记录医师",
            "八、主持人总结=主持人总结",
            "七：讨论意见=讨论意见",
            "六、诊疗经过(重点记录病情演变，抢救经过)=诊疗经过",
            "五、死亡诊断=死亡诊断",
            "四、死亡原因=死亡原因",
            "三、 死亡时间=死亡时间",
            "二、主    诉=主诉",
            "一、入院情况=入院情况",
            "本人姓名=姓名",
            "事件日期=讨论时间",
            "当前诊断=死亡诊断",
            "病历日期=记录时间",
            "讨论日期=讨论时间",
            "当前科室=科别",
            "参加讨论人员名单=参加人员",
            "讨论小结=结论"
    );

}